from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: KNCommandArchives.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSPMessages_pb2 as TSPMessages__pb2
from . import TSKArchives_pb2 as TSKArchives__pb2
from . import TSSArchives_pb2 as TSSArchives__pb2
from . import TSDArchives_pb2 as TSDArchives__pb2
from . import TSDCommandArchives_pb2 as TSDCommandArchives__pb2
from . import TSWPArchives_pb2 as TSWPArchives__pb2
from . import TSAArchives_pb2 as TSAArchives__pb2
from . import TSTArchives_pb2 as TSTArchives__pb2
from . import KNArchives_pb2 as KNArchives__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='KNCommandArchives.proto',
  package='KN',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x17KNCommandArchives.proto\x12\x02KN\x1a\x11TSPMessages.proto\x1a\x11TSKArchives.proto\x1a\x11TSSArchives.proto\x1a\x11TSDArchives.proto\x1a\x18TSDCommandArchives.proto\x1a\x12TSWPArchives.proto\x1a\x11TSAArchives.proto\x1a\x11TSTArchives.proto\x1a\x10KNArchives.proto\"\xd5\x02\n\x1aUIStateCommandGroupArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TSK.CommandGroupArchive\x12\x1f\n\x07uiState\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12\x10\n\x08property\x18\x03 \x02(\t\x12(\n\x10slideNodesToEdit\x18\x04 \x03(\x0b\x32\x0e.TSP.Reference\x12/\n\x17masterSlideNodesToApply\x18\x05 \x03(\x0b\x32\x0e.TSP.Reference\x12!\n\x0ethumbnailSizes\x18\x06 \x03(\x0b\x32\t.TSP.Size\x12*\n\x12selectedSlideNodes\x18\x07 \x03(\x0b\x32\x0e.TSP.Reference\x12\x31\n\x19restoreSelectedSlideNodes\x18\x08 \x03(\x0b\x32\x0e.TSP.Reference\"\xd6\x06\n\"CommandSlideInsertDrawablesArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1b\n\x08slide_id\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12!\n\tdrawables\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\x12)\n\x11working_drawables\x18\x12 \x03(\x0b\x32\x0e.TSP.Reference\x12+\n\targs_list\x18\x04 \x01(\x0b\x32\x18.KN.MixedIdOperationArgs\x12\x33\n+update_geometry_to_match_object_placeholder\x18\x05 \x02(\x08\x12\x45\n2ids_of_drawables_using_object_placeholder_geometry\x18\x06 \x03(\x0b\x32\t.TSP.UUID\x12\"\n\x1asage_placeholder_tags_list\x18\x07 \x03(\t\x12\x1f\n\x17instructional_text_list\x18\x14 \x03(\t\x12$\n\x0cundo_archive\x18\x08 \x01(\x0b\x32\x0e.TSP.Reference\x12\x12\n\nis_pasting\x18\t \x01(\x08\x12\x31\n\x19insert_build_descriptions\x18\n \x03(\x0b\x32\x0e.TSP.Reference\x12\x39\n!working_insert_build_descriptions\x18\x13 \x03(\x0b\x32\x0e.TSP.Reference\x12\x31\n\x19remove_build_descriptions\x18\x0b \x03(\x0b\x32\x0e.TSP.Reference\x12(\n remove_slide_specific_hyperlinks\x18\x0c \x01(\x08\x12%\n\x12\x63ustom_format_keys\x18\r \x03(\x0b\x32\t.TSP.UUID\x12*\n\"saved_next_untitled_resolver_index\x18\x10 \x01(\r\x12[\n=geometry_of_object_placeholder_for_comparison_to_restore_link\x18\x11 \x01(\x0b\x32\x14.TSD.GeometryArchive\"\xce\x01\n)CommandSlideSetPlaceholdersForTagsArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1b\n\x08slide_id\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12\x1d\n\x05infos\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\x12\x0c\n\x04tags\x18\x04 \x03(\t\x12!\n\told_infos\x18\x06 \x03(\x0b\x32\x0e.TSP.Reference\x12\x10\n\x08old_tags\x18\x05 \x03(\t\"\x9d\x01\n-CommandMasterSlideSetPlaceholderForTagArchive\x12<\n\x05super\x18\x01 \x02(\x0b\x32-.KN.CommandSlideSetPlaceholdersForTagsArchive\x12!\n\x0eplaceholder_id\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12\x0b\n\x03tag\x18\x03 \x01(\t\"\xb3\x01\n0CommandSlidePropagateSetPlaceholderForTagArchive\x12<\n\x05super\x18\x01 \x02(\x0b\x32-.KN.CommandSlideSetPlaceholdersForTagsArchive\x12!\n\x0eplaceholder_id\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12\x1e\n\x0boriginal_id\x18\x03 \x02(\x0b\x32\t.TSP.UUID\"\xfd\x03\n!CommandSlideRemoveDrawableArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1b\n\x08slide_id\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12\'\n\x0fsortedDrawables\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\x12+\n\targs_list\x18\x04 \x02(\x0b\x32\x18.KN.MixedIdOperationArgs\x12!\n\x19\x64rawable_indexes_for_undo\x18\n \x03(\r\x12\x17\n\x0fplaceholderTags\x18\x05 \x03(\t\x12\x1f\n\x17instructional_text_list\x18\x0b \x03(\t\x12\x31\n\x19insert_build_descriptions\x18\x06 \x03(\x0b\x32\x0e.TSP.Reference\x12\x31\n\x19remove_build_descriptions\x18\x07 \x03(\x0b\x32\x0e.TSP.Reference\x12\x43\n+drawables_using_object_placeholder_geometry\x18\x08 \x03(\x0b\x32\x0e.TSP.Reference\x12\x39\n!inverse_insert_hyperlink_commands\x18\t \x03(\x0b\x32\x0e.TSP.Reference\"\x82\x02\n%CommandSlideMoveDrawableZOrderArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12)\n\x11old_ordered_infos\x18\x04 \x03(\x0b\x32\x0e.TSP.Reference\x12\x30\n\targs_list\x18\x06 \x03(\x0b\x32\x1d.TSK.RearrangeIdOperationArgs\x12\x1b\n\x08slide_id\x18\x07 \x02(\x0b\x32\t.TSP.UUID\x12;\n#old_ordered_infos_on_slide_for_undo\x18\x08 \x03(\x0b\x32\x0e.TSP.Reference\"\xa7\x01\n\"CommandSlideNodeSetPropertyArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12)\n\x12slide_node_id_path\x18\x02 \x02(\x0b\x32\r.TSP.UUIDPath\x12\x10\n\x08property\x18\x03 \x02(\t\x12\x11\n\told_value\x18\x04 \x02(\x08\x12\r\n\x05value\x18\x05 \x02(\x08\"\xb0\x01\n+CommandSlideNodeSetViewStatePropertyArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12)\n\x12slide_node_id_path\x18\x02 \x02(\x0b\x32\r.TSP.UUIDPath\x12\x10\n\x08property\x18\x03 \x02(\t\x12\x11\n\told_value\x18\x04 \x02(\x08\x12\r\n\x05value\x18\x05 \x02(\x08\"\xb8\x01\n$CommandSlideSetBackgroundFillArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12$\n\rslide_id_path\x18\x02 \x02(\x0b\x32\r.TSP.UUIDPath\x12\"\n\x08old_fill\x18\x03 \x01(\x0b\x32\x10.TSD.FillArchive\x12\"\n\x08new_fill\x18\x04 \x02(\x0b\x32\x10.TSD.FillArchive\"\xb5\x01\n\x1b\x43ommandSlideSetStyleArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12$\n\rslide_id_path\x18\x02 \x02(\x0b\x32\r.TSP.UUIDPath\x12#\n\x0bslide_style\x18\x03 \x02(\x0b\x32\x0e.TSP.Reference\x12\'\n\x0fold_slide_style\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\"\xb3\x02\n(CommandShowMarkOutOfSyncRecordingArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1c\n\x04show\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12%\n\rold_recording\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12$\n\x1cold_is_recording_out_of_sync\x18\x04 \x01(\x08\x12$\n\x1cnew_is_recording_out_of_sync\x18\x05 \x01(\x08\x12(\n\x15old_modification_date\x18\x06 \x01(\x0b\x32\t.TSP.Date\x12(\n\x15new_modification_date\x18\x07 \x01(\x0b\x32\t.TSP.Date\"|\n0CommandShowMarkOutOfSyncRecordingIfNeededArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12$\n\x11out_of_sync_token\x18\x02 \x01(\x0b\x32\t.TSP.UUID\"\x8c\x01\n!CommandShowRemoveRecordingArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1c\n\x04show\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12%\n\rold_recording\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\"\xbc\x01\n\"CommandShowReplaceRecordingArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1c\n\x04show\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12-\n\x15replacement_recording\x18\x03 \x02(\x0b\x32\x0e.TSP.Reference\x12%\n\rold_recording\x18\x05 \x01(\x0b\x32\x0e.TSP.Reference\"\x82\x03\n\x1a\x43ommandShowSetValueArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1c\n\x04show\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12\x10\n\x08property\x18\x03 \x02(\t\x12?\n\told_value\x18\x04 \x02(\x0b\x32,.KN.CommandShowSetValueArchive.PropertyValue\x12?\n\tnew_value\x18\x05 \x02(\x0b\x32,.KN.CommandShowSetValueArchive.PropertyValue\x1a\x8d\x01\n\rPropertyValue\x12\x12\n\nbool_value\x18\x01 \x01(\x08\x12\x14\n\x0c\x64ouble_value\x18\x02 \x01(\x01\x12\x33\n\x0fshow_mode_value\x18\x03 \x01(\x0e\x32\x1a.KN.ShowArchive.KNShowMode\x12\x1d\n\nsize_value\x18\x04 \x01(\x0b\x32\t.TSP.Size\"\xf1\x06\n\x1d\x43ommandShowInsertSlideArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x32\n\x1aslide_nodes_being_inserted\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\x12:\n\"working_slide_nodes_being_inserted\x18\x0e \x03(\x0b\x32\x0e.TSP.Reference\x12\x33\n\x12inserted_args_list\x18\x03 \x03(\x0b\x32\x17.TSK.AddIdOperationArgs\x12\x38\n%ids_of_slide_nodes_with_depth_changes\x18\x04 \x03(\x0b\x32\t.TSP.UUID\x12\x30\n(depths_of_slide_nodes_with_depth_changes\x18\x05 \x03(\r\x12\x34\n,old_depths_of_slide_nodes_with_depth_changes\x18\x06 \x03(\r\x12\x34\n\x1cslide_nodes_for_depth_fix_up\x18\x07 \x03(\x0b\x32\x0e.TSP.Reference\x12.\n&depths_of_slide_nodes_for_depth_fix_up\x18\x08 \x03(\r\x12\x32\n*old_depths_of_slide_nodes_for_depth_fix_up\x18\t \x03(\r\x12\x34\n\x04kind\x18\n \x01(\x0e\x32&.KN.CommandShowInsertSlideArchive.Kind\x12\x33\n\x1bmaster_nodes_being_inserted\x18\x0b \x03(\x0b\x32\x0e.TSP.Reference\x12%\n\x12\x63ustom_format_keys\x18\x0c \x03(\x0b\x32\t.TSP.UUID\x12\x35\n-collapsed_state_of_slide_nodes_being_inserted\x18\r \x03(\x08\x12$\n\x0cundo_archive\x18\x0f \x01(\x0b\x32\x0e.TSP.Reference\"\\\n\x04Kind\x12\x14\n\x10kKindInsertSlide\x10\x00\x12\x1c\n\x18kKindInsertSlideForPaste\x10\x01\x12 \n\x1ckKindInsertSlideForDuplicate\x10\x02\"\xf4\x03\n\x1b\x43ommandShowMoveSlideArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x38\n slide_nodes_being_moved_linearly\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\x12;\n\x14rearranged_args_list\x18\x03 \x03(\x0b\x32\x1d.TSK.RearrangeIdOperationArgs\x12\x38\n%ids_of_slide_nodes_with_depth_changes\x18\x04 \x03(\x0b\x32\t.TSP.UUID\x12\x30\n(depths_of_slide_nodes_with_depth_changes\x18\x05 \x03(\r\x12\x34\n,old_depths_of_slide_nodes_with_depth_changes\x18\x06 \x03(\r\x12\x34\n\x1cslide_nodes_for_depth_fix_up\x18\x07 \x03(\x0b\x32\x0e.TSP.Reference\x12.\n&depths_of_slide_nodes_for_depth_fix_up\x18\x08 \x03(\r\x12\x32\n*old_depths_of_slide_nodes_for_depth_fix_up\x18\t \x03(\r\"\x9f\x04\n\x1d\x43ommandShowRemoveSlideArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x31\n\x19slide_nodes_being_removed\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\x12\x35\n\x11removed_args_list\x18\x03 \x03(\x0b\x32\x1a.TSK.RemoveIdOperationArgs\x12\x38\n%ids_of_slide_nodes_with_depth_changes\x18\x04 \x03(\x0b\x32\t.TSP.UUID\x12\x30\n(depths_of_slide_nodes_with_depth_changes\x18\x05 \x03(\r\x12\x34\n,old_depths_of_slide_nodes_with_depth_changes\x18\x06 \x03(\r\x12\x34\n\x1cslide_nodes_for_depth_fix_up\x18\x07 \x03(\x0b\x32\x0e.TSP.Reference\x12.\n&depths_of_slide_nodes_for_depth_fix_up\x18\x08 \x03(\r\x12\x32\n*old_depths_of_slide_nodes_for_depth_fix_up\x18\t \x03(\r\x12\x34\n,collapsed_state_of_slide_nodes_being_removed\x18\x0b \x03(\x08\"\xec\x03\n\x1d\x43ommandShowChangeThemeArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1c\n\x04show\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12\x1d\n\x05theme\x18\x03 \x02(\x0b\x32\x0e.TSP.Reference\x12!\n\told_theme\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1b\n\x13template_identifier\x18\x05 \x01(\t\x12\x1f\n\x17old_template_identifier\x18\x06 \x01(\t\x12W\n\x17identifier_to_style_map\x18\x07 \x01(\x0b\x32\x36.KN.CommandShowChangeThemeArchive.IdentifierToStyleMap\x12[\n\x1bold_identifier_to_style_map\x18\x08 \x01(\x0b\x32\x36.KN.CommandShowChangeThemeArchive.IdentifierToStyleMap\x1aS\n\x14IdentifierToStyleMap\x12;\n\x06styles\x18\x01 \x03(\x0b\x32+.TSS.StylesheetArchive.IdentifiedStyleEntry\"`\n!CommandShowChangeSlideSizeArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x17\n\x04size\x18\x02 \x02(\x0b\x32\t.TSP.Size\"\xbf\x01\n-CommandSetThemeCustomEffectTimingCurveArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x0c\n\x04name\x18\x02 \x01(\t\x12+\n\x0bpath_source\x18\x03 \x01(\x0b\x32\x16.TSD.PathSourceArchive\x12/\n\x0fold_path_source\x18\x04 \x01(\x0b\x32\x16.TSD.PathSourceArchive\"\x80\x02\n\x19\x43ommandMoveMastersArchive\x12:\n\x05super\x18\x01 \x02(\x0b\x32+.TSD.ContainerReorderChildrenCommandArchive\x12%\n\rmaster_slides\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\x12-\n\x15previous_indexes_keys\x18\x04 \x03(\x0b\x32\x0e.TSP.Reference\x12\x1f\n\x17previous_indexes_values\x18\x05 \x03(\r\x12\x30\n\x18\x66inal_master_arrangement\x18\x06 \x03(\x0b\x32\x0e.TSP.Reference\"\xe5\x01\n\x1a\x43ommandInsertMasterArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x33\n\x1bundo_master_change_commands\x18\x07 \x03(\x0b\x32\x0e.TSP.Reference\x12\x32\n*set_inserted_slide_as_default_master_slide\x18\x08 \x02(\x08\x12:\n\"undo_replacement_master_slide_node\x18\t \x01(\x0b\x32\x0e.TSP.Reference\"\xdf\x01\n#CommandPrimitiveInsertMasterArchive\x12\x39\n\x05super\x18\x01 \x02(\x0b\x32*.TSD.ContainerInsertChildrenCommandArchive\x12\x1e\n\x16was_inserted_with_drop\x18\x02 \x02(\x08\x12%\n\x12\x63ustom_format_keys\x18\x03 \x03(\x0b\x32\t.TSP.UUID\x12\x36\n\x1eprevious_classic_theme_records\x18\x04 \x03(\x0b\x32\x0e.TSP.Reference\"\xd7\x01\n\x1a\x43ommandRemoveMasterArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x35\n\x1dreplacement_master_slide_node\x18\x05 \x01(\x0b\x32\x0e.TSP.Reference\x12.\n\x16master_change_commands\x18\x06 \x03(\x0b\x32\x0e.TSP.Reference\x12.\n&default_master_slide_node_was_replaced\x18\x07 \x01(\x08\"\x98\x01\n#CommandPrimitiveRemoveMasterArchive\x12\x39\n\x05super\x18\x01 \x02(\x0b\x32*.TSD.ContainerRemoveChildrenCommandArchive\x12\x36\n\x1eprevious_classic_theme_records\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\"\xd4\x02\n\x1e\x43ommandSlideInsertBuildArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x30\n\x18insert_build_description\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12M\n$identifier_for_chunk_to_insert_after\x18\x03 \x01(\x0b\x32\x1f.KN.BuildChunkIdentifierArchive\x12\x1c\n\x14should_create_chunks\x18\x04 \x01(\x08\x12,\n\x14old_tuples_to_update\x18\x05 \x03(\x0b\x32\x0e.TSP.Reference\x12%\n\x1dwas_initialized_over_the_wire\x18\x06 \x01(\x08\x12\x1a\n\x12has_been_committed\x18\x07 \x01(\x08\"\x8d\x03\n\x1dInsertBuildDescriptionArchive\x12\x1b\n\x08slide_id\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12\'\n\x0f\x62uild_to_insert\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12(\n\x10\x63hunks_to_insert\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\x12\'\n\x1fshould_assign_chunk_identifiers\x18\x04 \x02(\x08\x12N\n%identifers_for_chunks_to_insert_after\x18\x05 \x03(\x0b\x32\x1f.KN.BuildChunkIdentifierArchive\x12(\n\x10tuples_to_update\x18\x06 \x03(\x0b\x32\x0e.TSP.Reference\x12\x43\n\x1a\x66\x61llback_chunk_identifiers\x18\x07 \x03(\x0b\x32\x1f.KN.BuildChunkIdentifierArchive\x12\x14\n\x0cis_for_paste\x18\x08 \x02(\x08\":\n\x11UndoObjectArchive\x12%\n\x05super\x18\x01 \x02(\x0b\x32\x16.TSD.UndoObjectArchive\"\x83\x03\n\x1e\x43ommandSlideRemoveBuildArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x30\n\x18remove_build_description\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12\x1d\n\x05\x62uild\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12(\n\x10\x63hunks_to_insert\x18\x04 \x03(\x0b\x32\x0e.TSP.Reference\x12O\n&identifiers_for_chunks_to_insert_after\x18\x05 \x03(\x0b\x32\x1f.KN.BuildChunkIdentifierArchive\x12,\n\x14old_tuples_to_update\x18\x06 \x03(\x0b\x32\x0e.TSP.Reference\x12\x43\n\x1a\x66\x61llback_chunk_identifiers\x18\x07 \x03(\x0b\x32\x1f.KN.BuildChunkIdentifierArchive\"\xca\x01\n\x1dRemoveBuildDescriptionArchive\x12\x1b\n\x08slide_id\x18\x01 \x01(\x0b\x32\t.TSP.UUID\x12\x1b\n\x08\x62uild_id\x18\x02 \x01(\x0b\x32\t.TSP.UUID\x12\x1c\n\x14should_remove_chunks\x18\x03 \x01(\x08\x12\'\n\x1fshould_remove_chunk_identifiers\x18\x04 \x01(\x08\x12(\n\x10tuples_to_update\x18\x05 \x03(\x0b\x32\x0e.TSP.Reference\"\xfe\x02\n#CommandSlideInsertBuildChunkArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1b\n\x08slide_id\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12\'\n\x0f\x63hunk_to_insert\x18\x03 \x02(\x0b\x32\x0e.TSP.Reference\x12M\n$identifier_for_chunk_to_insert_after\x18\x04 \x01(\x0b\x32\x1f.KN.BuildChunkIdentifierArchive\x12(\n\x10tuples_to_update\x18\x05 \x03(\x0b\x32\x0e.TSP.Reference\x12,\n\x14old_tuples_to_update\x18\x06 \x03(\x0b\x32\x0e.TSP.Reference\x12\x1e\n\x16needs_selection_update\x18\x07 \x01(\x08\x12&\n\x1eshould_assign_chunk_identifier\x18\x08 \x01(\x08\"\x9d\x03\n#CommandSlideRemoveBuildChunkArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1b\n\x08slide_id\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12%\n\rremoved_chunk\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12G\n\x1eidentifier_for_chunk_to_remove\x18\x04 \x01(\x0b\x32\x1f.KN.BuildChunkIdentifierArchive\x12M\n$identifier_for_chunk_to_insert_after\x18\x05 \x01(\x0b\x32\x1f.KN.BuildChunkIdentifierArchive\x12(\n\x10tuples_to_update\x18\x06 \x03(\x0b\x32\x0e.TSP.Reference\x12,\n\x14old_tuples_to_update\x18\x07 \x03(\x0b\x32\x0e.TSP.Reference\x12\x1e\n\x16needs_selection_update\x18\x08 \x01(\x08\"\xfd\x03\n\"CommandSlideMoveBuildChunksArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12G\n\x1eidentifiers_for_chunks_to_move\x18\x02 \x03(\x0b\x32\x1f.KN.BuildChunkIdentifierArchive\x12M\n$identifiers_for_chunks_to_move_after\x18\x03 \x03(\x0b\x32\x1f.KN.BuildChunkIdentifierArchive\x12V\n-identifiers_for_chunks_to_move_after_for_undo\x18\x04 \x03(\x0b\x32\x1f.KN.BuildChunkIdentifierArchive\x12(\n\x10tuples_to_update\x18\x05 \x03(\x0b\x32\x0e.TSP.Reference\x12,\n\x14old_tuples_to_update\x18\x06 \x03(\x0b\x32\x0e.TSP.Reference\x12k\nBidentifiers_for_chunks_to_move_including_clustered_inactive_chunks\x18\x07 \x03(\x0b\x32\x1f.KN.BuildChunkIdentifierArchive\"\xd8\x06\n\x1b\x43ommandBuildSetValueArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1d\n\x05tuple\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12%\n\rchunks_to_add\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\x12O\n&identifiers_for_chunks_to_insert_after\x18\x04 \x03(\x0b\x32\x1f.KN.BuildChunkIdentifierArchive\x12I\n identifiers_for_chunks_to_remove\x18\x05 \x03(\x0b\x32\x1f.KN.BuildChunkIdentifierArchive\x12(\n\x10tuples_to_update\x18\x06 \x03(\x0b\x32\x0e.TSP.Reference\x12\x33\n\x1bold_tuple_for_main_property\x18\x07 \x01(\x0b\x32\x0e.TSP.Reference\x12=\n%old_tuples_to_update_for_sub_commands\x18\x08 \x03(\x0b\x32\x0e.TSP.Reference\x12\x45\n\x1cidentifiers_for_added_chunks\x18\t \x03(\x0b\x32\x1f.KN.BuildChunkIdentifierArchive\x12>\n\x15generated_identifiers\x18\n \x03(\x0b\x32\x1f.KN.BuildChunkIdentifierArchive\x12&\n\x0eremoved_chunks\x18\x0b \x03(\x0b\x32\x0e.TSP.Reference\x12W\n.identifiers_for_chunks_prior_to_removed_chunks\x18\x0c \x03(\x0b\x32\x1f.KN.BuildChunkIdentifierArchive\x12\x19\n\x11old_chunk_ID_seed\x18\r \x01(\r\x12>\n\x15old_chunk_identifiers\x18\x0e \x03(\x0b\x32\x1f.KN.BuildChunkIdentifierArchive\x12\x32\n\x1a\x63hunks_removed_during_undo\x18\x0f \x03(\x0b\x32\x0e.TSP.Reference\"\xc2\x01\n\'CommandBuildUpdateChunkReferentsArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1b\n\x08\x62uild_id\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12(\n\x10tuples_to_update\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\x12,\n\x14old_tuples_to_update\x18\x04 \x03(\x0b\x32\x0e.TSP.Reference\"\xb5\x08\n#CommandBuildUpdateChunkCountArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1b\n\x08slide_id\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12\x1f\n\x0c\x64rawable_ids\x18\x03 \x03(\x0b\x32\t.TSP.UUID\x12\x36\n\x1e\x65xpected_delivery_style_tuples\x18\x04 \x03(\x0b\x32\x0e.TSP.Reference\x12%\n\rchunks_to_add\x18\x05 \x03(\x0b\x32\x0e.TSP.Reference\x12O\n&identifiers_for_chunks_to_insert_after\x18\x06 \x03(\x0b\x32\x1f.KN.BuildChunkIdentifierArchive\x12I\n identifiers_for_chunks_to_remove\x18\x07 \x03(\x0b\x32\x1f.KN.BuildChunkIdentifierArchive\x12(\n\x10tuples_to_update\x18\x08 \x03(\x0b\x32\x0e.TSP.Reference\x12\x34\n,needs_async_process_changes_selection_update\x18\t \x01(\x08\x12,\n\x14old_tuples_to_update\x18\n \x03(\x0b\x32\x0e.TSP.Reference\x12\x45\n\x1cidentifiers_for_added_chunks\x18\x0b \x03(\x0b\x32\x1f.KN.BuildChunkIdentifierArchive\x12>\n\x15generated_identifiers\x18\x0c \x03(\x0b\x32\x1f.KN.BuildChunkIdentifierArchive\x12&\n\x0eremoved_chunks\x18\r \x03(\x0b\x32\x0e.TSP.Reference\x12W\n.identifiers_for_chunks_prior_to_removed_chunks\x18\x0e \x03(\x0b\x32\x1f.KN.BuildChunkIdentifierArchive\x12\x31\n\x19old_delivery_style_tuples\x18\x0f \x03(\x0b\x32\x0e.TSP.Reference\x12\x1a\n\x12old_chunk_ID_seeds\x18\x10 \x03(\r\x12>\n\x15old_chunk_identifiers\x18\x11 \x03(\x0b\x32\x1f.KN.BuildChunkIdentifierArchive\x12&\n\x0eworking_builds\x18\x12 \x03(\x0b\x32\x0e.TSP.Reference\x12\x32\n\x1a\x63hunks_removed_during_undo\x18\x13 \x03(\x0b\x32\x0e.TSP.Reference\x12\x30\n\x18\x63hunks_added_during_undo\x18\x14 \x03(\x0b\x32\x0e.TSP.Reference\"\x9e\x01\n CommandBuildChunkSetValueArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12(\n\x10tuples_to_update\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\x12,\n\x14old_tuples_to_update\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\"\xf1\x01\n CommandTransitionSetValueArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12)\n\x12slide_node_id_path\x18\x02 \x02(\x0b\x32\r.TSP.UUIDPath\x12\x37\n\x0eold_attributes\x18\x03 \x01(\x0b\x32\x1f.KN.TransitionAttributesArchive\x12\x33\n\nattributes\x18\x04 \x01(\x0b\x32\x1f.KN.TransitionAttributesArchive\x12\x10\n\x08property\x18\x05 \x01(\t\"\xe6\x01\n*CommandShowSetSlideNumberVisibilityArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1d\n\x15slide_numbers_visible\x18\x03 \x02(\x08\x12-\n\x1aids_of_slide_nodes_to_skip\x18\x04 \x03(\x0b\x32\t.TSP.UUID\x12\x35\n\"ids_of_slide_nodes_already_correct\x18\x05 \x03(\x0b\x32\t.TSP.UUID\x12\x0f\n\x07is_undo\x18\x06 \x02(\x08\"\x9d\x01\n$CommandMasterSetThumbnailTextArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1c\n\tmaster_id\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12\x0f\n\x07is_body\x18\x03 \x02(\x08\x12\x10\n\x08new_text\x18\x04 \x01(\t\x12\x10\n\x08old_text\x18\x05 \x01(\t\"\x93\x02\n!CommandMasterSetBodyStylesArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1c\n\tmaster_id\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12,\n\x14new_paragraph_styles\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\x12\'\n\x0fnew_list_styles\x18\x04 \x03(\x0b\x32\x0e.TSP.Reference\x12,\n\x14old_paragraph_styles\x18\x05 \x03(\x0b\x32\x0e.TSP.Reference\x12\'\n\x0fold_list_styles\x18\x06 \x03(\x0b\x32\x0e.TSP.Reference\"\xf9\x01\n\x1f\x43ommandChangeMasterSlideArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12$\n\rslide_id_path\x18\x02 \x02(\x0b\x32\r.TSP.UUIDPath\x12#\n\x0bmaster_node\x18\x03 \x02(\x0b\x32\x0e.TSP.Reference\x12\'\n\x0fold_master_node\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12\x14\n\x0cis_undo_redo\x18\x05 \x02(\x08\x12(\n\x10target_prototype\x18\x06 \x01(\x0b\x32\x0e.TSP.Reference\"\xb8\x01\n%CommandSlidePrimitiveSetMasterArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12$\n\rslide_id_path\x18\x02 \x02(\x0b\x32\r.TSP.UUIDPath\x12\x1c\n\tmaster_id\x18\x03 \x02(\x0b\x32\t.TSP.UUID\x12\'\n\x0fold_master_node\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\"{\n/CommandSlideResetMasterBackgroundObjectsArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12$\n\rslide_id_path\x18\x02 \x01(\x0b\x32\r.TSP.UUIDPath\"\xa8\x01\n\x18\x43ommandShowSetSoundtrack\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1c\n\x04show\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\"\n\nsoundtrack\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12&\n\x0eold_soundtrack\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\"\x82\x03\n\x19\x43ommandSoundtrackSetValue\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12 \n\rsoundtrack_id\x18\x02 \x01(\x0b\x32\t.TSP.UUID\x12\x10\n\x08property\x18\x03 \x01(\t\x12>\n\told_value\x18\x04 \x01(\x0b\x32+.KN.CommandSoundtrackSetValue.PropertyValue\x12>\n\tnew_value\x18\x05 \x01(\x0b\x32+.KN.CommandSoundtrackSetValue.PropertyValue\x1a\x8c\x01\n\rPropertyValue\x12\x14\n\x0c\x64ouble_value\x18\x01 \x01(\x01\x12\x31\n\nmode_value\x18\x02 \x01(\x0e\x32\x1d.KN.Soundtrack.SoundtrackMode\x12\x32\n\x16media_reference_values\x18\x03 \x03(\x0b\x32\x12.TSP.DataReference\"\xda\x01\n!CommandSlideUpdateMasterDrawables\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1b\n\x08slide_id\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12\x42\n\x1bid_placement_operation_args\x18\x03 \x03(\x0b\x32\x1d.TSK.IdPlacementOperationArgs\x12\x30\n\x18old_child_infos_for_undo\x18\x04 \x03(\x0b\x32\x0e.TSP.Reference\"\xfb\x01\n\x1f\x43hartInfoGeometryCommandArchive\x12.\n\x05super\x18\x01 \x02(\x0b\x32\x1f.TSD.InfoGeometryCommandArchive\x12*\n\x16previous_legend_offset\x18\x02 \x02(\x0b\x32\n.TSP.Point\x12\'\n\x14previous_legend_size\x18\x03 \x02(\x0b\x32\t.TSP.Size\x12*\n\x16\x61\x64justed_legend_offset\x18\x04 \x02(\x0b\x32\n.TSP.Point\x12\'\n\x14\x61\x64justed_legend_size\x18\x05 \x02(\x0b\x32\t.TSP.Size\"\x8b\x02\n!CanvasSelectionTransformerArchive\x12P\n\x12transformer_helper\x18\x01 \x02(\x0b\x32\x34.TSD.InfoCollectionSelectionTransformerHelperArchive\x12\x38\n\x0f\x62uild_chunk_ids\x18\x02 \x03(\x0b\x32\x1f.KN.BuildChunkIdentifierArchive\x12#\n\x10\x61\x63tion_build_ids\x18\x03 \x03(\x0b\x32\t.TSP.UUID\x12\x35\n\"originally_selected_drawable_uuids\x18\x04 \x03(\x0b\x32\t.TSP.UUID\"(\n&ActionGhostSelectionTransformerArchive\"Q\n#DocumentSelectionTransformerArchive\x12*\n\x12\x64ocument_selection\x18\x01 \x02(\x0b\x32\x0e.TSP.Reference\"y\n%NoteCanvasSelectionTransformerArchive\x12P\n\x12transformer_helper\x18\x01 \x02(\x0b\x32\x34.TSD.InfoCollectionSelectionTransformerHelperArchive\"\x8a\x01\n(OutlineCanvasSelectionTransformerArchive\x12\x34\n\x1c\x63\x61nvas_selection_transformer\x18\x01 \x02(\x0b\x32\x0e.TSP.Reference\x12(\n\x11storage_uuid_path\x18\x02 \x01(\x0b\x32\r.TSP.UUIDPath\"\xcd\x01\n0SlideCollectionSelectionTransformerHelperArchive\x12\"\n\x0bslide_nodes\x18\x01 \x03(\x0b\x32\r.TSP.UUIDPath\x12)\n\x12slide_node_to_edit\x18\x02 \x01(\x0b\x32\r.TSP.UUIDPath\x12!\n\x19slide_collection_is_theme\x18\x03 \x01(\x08\x12\'\n\x1fprevious_primary_selected_index\x18\x04 \x01(\r\"~\n*SlideCollectionSelectionTransformerArchive\x12P\n\x12transformer_helper\x18\x01 \x02(\x0b\x32\x34.KN.SlideCollectionSelectionTransformerHelperArchive\"\xda\x01\n\"OutlineSelectionTransformerArchive\x12P\n\x12transformer_helper\x18\x01 \x02(\x0b\x32\x34.KN.SlideCollectionSelectionTransformerHelperArchive\x12,\n$can_have_range_in_selected_paragraph\x18\x02 \x01(\x08\x12\x34\n\x19selection_range_addresses\x18\x03 \x03(\x0b\x32\x11.TSK.RangeAddress*=\n\x11\x41nimationReferent\x12\x14\n\x10kRelativeToStart\x10\x01\x12\x12\n\x0ekRelativeToEnd\x10\x02')
  ,
  dependencies=[TSPMessages__pb2.DESCRIPTOR,TSKArchives__pb2.DESCRIPTOR,TSSArchives__pb2.DESCRIPTOR,TSDArchives__pb2.DESCRIPTOR,TSDCommandArchives__pb2.DESCRIPTOR,TSWPArchives__pb2.DESCRIPTOR,TSAArchives__pb2.DESCRIPTOR,TSTArchives__pb2.DESCRIPTOR,KNArchives__pb2.DESCRIPTOR,])

_ANIMATIONREFERENT = _descriptor.EnumDescriptor(
  name='AnimationReferent',
  full_name='KN.AnimationReferent',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kRelativeToStart', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kRelativeToEnd', index=1, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=17161,
  serialized_end=17222,
)
_sym_db.RegisterEnumDescriptor(_ANIMATIONREFERENT)

AnimationReferent = enum_type_wrapper.EnumTypeWrapper(_ANIMATIONREFERENT)
kRelativeToStart = 1
kRelativeToEnd = 2


_COMMANDSHOWINSERTSLIDEARCHIVE_KIND = _descriptor.EnumDescriptor(
  name='Kind',
  full_name='KN.CommandShowInsertSlideArchive.Kind',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kKindInsertSlide', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindInsertSlideForPaste', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindInsertSlideForDuplicate', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5403,
  serialized_end=5495,
)
_sym_db.RegisterEnumDescriptor(_COMMANDSHOWINSERTSLIDEARCHIVE_KIND)


_UISTATECOMMANDGROUPARCHIVE = _descriptor.Descriptor(
  name='UIStateCommandGroupArchive',
  full_name='KN.UIStateCommandGroupArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.UIStateCommandGroupArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uiState', full_name='KN.UIStateCommandGroupArchive.uiState', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='property', full_name='KN.UIStateCommandGroupArchive.property', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slideNodesToEdit', full_name='KN.UIStateCommandGroupArchive.slideNodesToEdit', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='masterSlideNodesToApply', full_name='KN.UIStateCommandGroupArchive.masterSlideNodesToApply', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thumbnailSizes', full_name='KN.UIStateCommandGroupArchive.thumbnailSizes', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selectedSlideNodes', full_name='KN.UIStateCommandGroupArchive.selectedSlideNodes', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='restoreSelectedSlideNodes', full_name='KN.UIStateCommandGroupArchive.restoreSelectedSlideNodes', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=210,
  serialized_end=551,
)


_COMMANDSLIDEINSERTDRAWABLESARCHIVE = _descriptor.Descriptor(
  name='CommandSlideInsertDrawablesArchive',
  full_name='KN.CommandSlideInsertDrawablesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandSlideInsertDrawablesArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_id', full_name='KN.CommandSlideInsertDrawablesArchive.slide_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drawables', full_name='KN.CommandSlideInsertDrawablesArchive.drawables', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='working_drawables', full_name='KN.CommandSlideInsertDrawablesArchive.working_drawables', index=3,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='args_list', full_name='KN.CommandSlideInsertDrawablesArchive.args_list', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update_geometry_to_match_object_placeholder', full_name='KN.CommandSlideInsertDrawablesArchive.update_geometry_to_match_object_placeholder', index=5,
      number=5, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ids_of_drawables_using_object_placeholder_geometry', full_name='KN.CommandSlideInsertDrawablesArchive.ids_of_drawables_using_object_placeholder_geometry', index=6,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sage_placeholder_tags_list', full_name='KN.CommandSlideInsertDrawablesArchive.sage_placeholder_tags_list', index=7,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instructional_text_list', full_name='KN.CommandSlideInsertDrawablesArchive.instructional_text_list', index=8,
      number=20, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_archive', full_name='KN.CommandSlideInsertDrawablesArchive.undo_archive', index=9,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_pasting', full_name='KN.CommandSlideInsertDrawablesArchive.is_pasting', index=10,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='insert_build_descriptions', full_name='KN.CommandSlideInsertDrawablesArchive.insert_build_descriptions', index=11,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='working_insert_build_descriptions', full_name='KN.CommandSlideInsertDrawablesArchive.working_insert_build_descriptions', index=12,
      number=19, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove_build_descriptions', full_name='KN.CommandSlideInsertDrawablesArchive.remove_build_descriptions', index=13,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove_slide_specific_hyperlinks', full_name='KN.CommandSlideInsertDrawablesArchive.remove_slide_specific_hyperlinks', index=14,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_format_keys', full_name='KN.CommandSlideInsertDrawablesArchive.custom_format_keys', index=15,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='saved_next_untitled_resolver_index', full_name='KN.CommandSlideInsertDrawablesArchive.saved_next_untitled_resolver_index', index=16,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geometry_of_object_placeholder_for_comparison_to_restore_link', full_name='KN.CommandSlideInsertDrawablesArchive.geometry_of_object_placeholder_for_comparison_to_restore_link', index=17,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=554,
  serialized_end=1408,
)


_COMMANDSLIDESETPLACEHOLDERSFORTAGSARCHIVE = _descriptor.Descriptor(
  name='CommandSlideSetPlaceholdersForTagsArchive',
  full_name='KN.CommandSlideSetPlaceholdersForTagsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandSlideSetPlaceholdersForTagsArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_id', full_name='KN.CommandSlideSetPlaceholdersForTagsArchive.slide_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='infos', full_name='KN.CommandSlideSetPlaceholdersForTagsArchive.infos', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='KN.CommandSlideSetPlaceholdersForTagsArchive.tags', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_infos', full_name='KN.CommandSlideSetPlaceholdersForTagsArchive.old_infos', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_tags', full_name='KN.CommandSlideSetPlaceholdersForTagsArchive.old_tags', index=5,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1411,
  serialized_end=1617,
)


_COMMANDMASTERSLIDESETPLACEHOLDERFORTAGARCHIVE = _descriptor.Descriptor(
  name='CommandMasterSlideSetPlaceholderForTagArchive',
  full_name='KN.CommandMasterSlideSetPlaceholderForTagArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandMasterSlideSetPlaceholderForTagArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='placeholder_id', full_name='KN.CommandMasterSlideSetPlaceholderForTagArchive.placeholder_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tag', full_name='KN.CommandMasterSlideSetPlaceholderForTagArchive.tag', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1620,
  serialized_end=1777,
)


_COMMANDSLIDEPROPAGATESETPLACEHOLDERFORTAGARCHIVE = _descriptor.Descriptor(
  name='CommandSlidePropagateSetPlaceholderForTagArchive',
  full_name='KN.CommandSlidePropagateSetPlaceholderForTagArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandSlidePropagateSetPlaceholderForTagArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='placeholder_id', full_name='KN.CommandSlidePropagateSetPlaceholderForTagArchive.placeholder_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='original_id', full_name='KN.CommandSlidePropagateSetPlaceholderForTagArchive.original_id', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1780,
  serialized_end=1959,
)


_COMMANDSLIDEREMOVEDRAWABLEARCHIVE = _descriptor.Descriptor(
  name='CommandSlideRemoveDrawableArchive',
  full_name='KN.CommandSlideRemoveDrawableArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandSlideRemoveDrawableArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_id', full_name='KN.CommandSlideRemoveDrawableArchive.slide_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sortedDrawables', full_name='KN.CommandSlideRemoveDrawableArchive.sortedDrawables', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='args_list', full_name='KN.CommandSlideRemoveDrawableArchive.args_list', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drawable_indexes_for_undo', full_name='KN.CommandSlideRemoveDrawableArchive.drawable_indexes_for_undo', index=4,
      number=10, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='placeholderTags', full_name='KN.CommandSlideRemoveDrawableArchive.placeholderTags', index=5,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instructional_text_list', full_name='KN.CommandSlideRemoveDrawableArchive.instructional_text_list', index=6,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='insert_build_descriptions', full_name='KN.CommandSlideRemoveDrawableArchive.insert_build_descriptions', index=7,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove_build_descriptions', full_name='KN.CommandSlideRemoveDrawableArchive.remove_build_descriptions', index=8,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drawables_using_object_placeholder_geometry', full_name='KN.CommandSlideRemoveDrawableArchive.drawables_using_object_placeholder_geometry', index=9,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverse_insert_hyperlink_commands', full_name='KN.CommandSlideRemoveDrawableArchive.inverse_insert_hyperlink_commands', index=10,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1962,
  serialized_end=2471,
)


_COMMANDSLIDEMOVEDRAWABLEZORDERARCHIVE = _descriptor.Descriptor(
  name='CommandSlideMoveDrawableZOrderArchive',
  full_name='KN.CommandSlideMoveDrawableZOrderArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandSlideMoveDrawableZOrderArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_ordered_infos', full_name='KN.CommandSlideMoveDrawableZOrderArchive.old_ordered_infos', index=1,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='args_list', full_name='KN.CommandSlideMoveDrawableZOrderArchive.args_list', index=2,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_id', full_name='KN.CommandSlideMoveDrawableZOrderArchive.slide_id', index=3,
      number=7, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_ordered_infos_on_slide_for_undo', full_name='KN.CommandSlideMoveDrawableZOrderArchive.old_ordered_infos_on_slide_for_undo', index=4,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2474,
  serialized_end=2732,
)


_COMMANDSLIDENODESETPROPERTYARCHIVE = _descriptor.Descriptor(
  name='CommandSlideNodeSetPropertyArchive',
  full_name='KN.CommandSlideNodeSetPropertyArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandSlideNodeSetPropertyArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_node_id_path', full_name='KN.CommandSlideNodeSetPropertyArchive.slide_node_id_path', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='property', full_name='KN.CommandSlideNodeSetPropertyArchive.property', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_value', full_name='KN.CommandSlideNodeSetPropertyArchive.old_value', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='KN.CommandSlideNodeSetPropertyArchive.value', index=4,
      number=5, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2735,
  serialized_end=2902,
)


_COMMANDSLIDENODESETVIEWSTATEPROPERTYARCHIVE = _descriptor.Descriptor(
  name='CommandSlideNodeSetViewStatePropertyArchive',
  full_name='KN.CommandSlideNodeSetViewStatePropertyArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandSlideNodeSetViewStatePropertyArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_node_id_path', full_name='KN.CommandSlideNodeSetViewStatePropertyArchive.slide_node_id_path', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='property', full_name='KN.CommandSlideNodeSetViewStatePropertyArchive.property', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_value', full_name='KN.CommandSlideNodeSetViewStatePropertyArchive.old_value', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='KN.CommandSlideNodeSetViewStatePropertyArchive.value', index=4,
      number=5, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2905,
  serialized_end=3081,
)


_COMMANDSLIDESETBACKGROUNDFILLARCHIVE = _descriptor.Descriptor(
  name='CommandSlideSetBackgroundFillArchive',
  full_name='KN.CommandSlideSetBackgroundFillArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandSlideSetBackgroundFillArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_id_path', full_name='KN.CommandSlideSetBackgroundFillArchive.slide_id_path', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_fill', full_name='KN.CommandSlideSetBackgroundFillArchive.old_fill', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_fill', full_name='KN.CommandSlideSetBackgroundFillArchive.new_fill', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3084,
  serialized_end=3268,
)


_COMMANDSLIDESETSTYLEARCHIVE = _descriptor.Descriptor(
  name='CommandSlideSetStyleArchive',
  full_name='KN.CommandSlideSetStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandSlideSetStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_id_path', full_name='KN.CommandSlideSetStyleArchive.slide_id_path', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_style', full_name='KN.CommandSlideSetStyleArchive.slide_style', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_slide_style', full_name='KN.CommandSlideSetStyleArchive.old_slide_style', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3271,
  serialized_end=3452,
)


_COMMANDSHOWMARKOUTOFSYNCRECORDINGARCHIVE = _descriptor.Descriptor(
  name='CommandShowMarkOutOfSyncRecordingArchive',
  full_name='KN.CommandShowMarkOutOfSyncRecordingArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandShowMarkOutOfSyncRecordingArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show', full_name='KN.CommandShowMarkOutOfSyncRecordingArchive.show', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_recording', full_name='KN.CommandShowMarkOutOfSyncRecordingArchive.old_recording', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_is_recording_out_of_sync', full_name='KN.CommandShowMarkOutOfSyncRecordingArchive.old_is_recording_out_of_sync', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_is_recording_out_of_sync', full_name='KN.CommandShowMarkOutOfSyncRecordingArchive.new_is_recording_out_of_sync', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_modification_date', full_name='KN.CommandShowMarkOutOfSyncRecordingArchive.old_modification_date', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_modification_date', full_name='KN.CommandShowMarkOutOfSyncRecordingArchive.new_modification_date', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3455,
  serialized_end=3762,
)


_COMMANDSHOWMARKOUTOFSYNCRECORDINGIFNEEDEDARCHIVE = _descriptor.Descriptor(
  name='CommandShowMarkOutOfSyncRecordingIfNeededArchive',
  full_name='KN.CommandShowMarkOutOfSyncRecordingIfNeededArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandShowMarkOutOfSyncRecordingIfNeededArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='out_of_sync_token', full_name='KN.CommandShowMarkOutOfSyncRecordingIfNeededArchive.out_of_sync_token', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3764,
  serialized_end=3888,
)


_COMMANDSHOWREMOVERECORDINGARCHIVE = _descriptor.Descriptor(
  name='CommandShowRemoveRecordingArchive',
  full_name='KN.CommandShowRemoveRecordingArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandShowRemoveRecordingArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show', full_name='KN.CommandShowRemoveRecordingArchive.show', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_recording', full_name='KN.CommandShowRemoveRecordingArchive.old_recording', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3891,
  serialized_end=4031,
)


_COMMANDSHOWREPLACERECORDINGARCHIVE = _descriptor.Descriptor(
  name='CommandShowReplaceRecordingArchive',
  full_name='KN.CommandShowReplaceRecordingArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandShowReplaceRecordingArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show', full_name='KN.CommandShowReplaceRecordingArchive.show', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replacement_recording', full_name='KN.CommandShowReplaceRecordingArchive.replacement_recording', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_recording', full_name='KN.CommandShowReplaceRecordingArchive.old_recording', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4034,
  serialized_end=4222,
)


_COMMANDSHOWSETVALUEARCHIVE_PROPERTYVALUE = _descriptor.Descriptor(
  name='PropertyValue',
  full_name='KN.CommandShowSetValueArchive.PropertyValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bool_value', full_name='KN.CommandShowSetValueArchive.PropertyValue.bool_value', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='double_value', full_name='KN.CommandShowSetValueArchive.PropertyValue.double_value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show_mode_value', full_name='KN.CommandShowSetValueArchive.PropertyValue.show_mode_value', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size_value', full_name='KN.CommandShowSetValueArchive.PropertyValue.size_value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4470,
  serialized_end=4611,
)

_COMMANDSHOWSETVALUEARCHIVE = _descriptor.Descriptor(
  name='CommandShowSetValueArchive',
  full_name='KN.CommandShowSetValueArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandShowSetValueArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show', full_name='KN.CommandShowSetValueArchive.show', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='property', full_name='KN.CommandShowSetValueArchive.property', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_value', full_name='KN.CommandShowSetValueArchive.old_value', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_value', full_name='KN.CommandShowSetValueArchive.new_value', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_COMMANDSHOWSETVALUEARCHIVE_PROPERTYVALUE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4225,
  serialized_end=4611,
)


_COMMANDSHOWINSERTSLIDEARCHIVE = _descriptor.Descriptor(
  name='CommandShowInsertSlideArchive',
  full_name='KN.CommandShowInsertSlideArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandShowInsertSlideArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_nodes_being_inserted', full_name='KN.CommandShowInsertSlideArchive.slide_nodes_being_inserted', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='working_slide_nodes_being_inserted', full_name='KN.CommandShowInsertSlideArchive.working_slide_nodes_being_inserted', index=2,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inserted_args_list', full_name='KN.CommandShowInsertSlideArchive.inserted_args_list', index=3,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ids_of_slide_nodes_with_depth_changes', full_name='KN.CommandShowInsertSlideArchive.ids_of_slide_nodes_with_depth_changes', index=4,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='depths_of_slide_nodes_with_depth_changes', full_name='KN.CommandShowInsertSlideArchive.depths_of_slide_nodes_with_depth_changes', index=5,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_depths_of_slide_nodes_with_depth_changes', full_name='KN.CommandShowInsertSlideArchive.old_depths_of_slide_nodes_with_depth_changes', index=6,
      number=6, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_nodes_for_depth_fix_up', full_name='KN.CommandShowInsertSlideArchive.slide_nodes_for_depth_fix_up', index=7,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='depths_of_slide_nodes_for_depth_fix_up', full_name='KN.CommandShowInsertSlideArchive.depths_of_slide_nodes_for_depth_fix_up', index=8,
      number=8, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_depths_of_slide_nodes_for_depth_fix_up', full_name='KN.CommandShowInsertSlideArchive.old_depths_of_slide_nodes_for_depth_fix_up', index=9,
      number=9, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kind', full_name='KN.CommandShowInsertSlideArchive.kind', index=10,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master_nodes_being_inserted', full_name='KN.CommandShowInsertSlideArchive.master_nodes_being_inserted', index=11,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_format_keys', full_name='KN.CommandShowInsertSlideArchive.custom_format_keys', index=12,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collapsed_state_of_slide_nodes_being_inserted', full_name='KN.CommandShowInsertSlideArchive.collapsed_state_of_slide_nodes_being_inserted', index=13,
      number=13, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_archive', full_name='KN.CommandShowInsertSlideArchive.undo_archive', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COMMANDSHOWINSERTSLIDEARCHIVE_KIND,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4614,
  serialized_end=5495,
)


_COMMANDSHOWMOVESLIDEARCHIVE = _descriptor.Descriptor(
  name='CommandShowMoveSlideArchive',
  full_name='KN.CommandShowMoveSlideArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandShowMoveSlideArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_nodes_being_moved_linearly', full_name='KN.CommandShowMoveSlideArchive.slide_nodes_being_moved_linearly', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rearranged_args_list', full_name='KN.CommandShowMoveSlideArchive.rearranged_args_list', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ids_of_slide_nodes_with_depth_changes', full_name='KN.CommandShowMoveSlideArchive.ids_of_slide_nodes_with_depth_changes', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='depths_of_slide_nodes_with_depth_changes', full_name='KN.CommandShowMoveSlideArchive.depths_of_slide_nodes_with_depth_changes', index=4,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_depths_of_slide_nodes_with_depth_changes', full_name='KN.CommandShowMoveSlideArchive.old_depths_of_slide_nodes_with_depth_changes', index=5,
      number=6, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_nodes_for_depth_fix_up', full_name='KN.CommandShowMoveSlideArchive.slide_nodes_for_depth_fix_up', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='depths_of_slide_nodes_for_depth_fix_up', full_name='KN.CommandShowMoveSlideArchive.depths_of_slide_nodes_for_depth_fix_up', index=7,
      number=8, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_depths_of_slide_nodes_for_depth_fix_up', full_name='KN.CommandShowMoveSlideArchive.old_depths_of_slide_nodes_for_depth_fix_up', index=8,
      number=9, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5498,
  serialized_end=5998,
)


_COMMANDSHOWREMOVESLIDEARCHIVE = _descriptor.Descriptor(
  name='CommandShowRemoveSlideArchive',
  full_name='KN.CommandShowRemoveSlideArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandShowRemoveSlideArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_nodes_being_removed', full_name='KN.CommandShowRemoveSlideArchive.slide_nodes_being_removed', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='removed_args_list', full_name='KN.CommandShowRemoveSlideArchive.removed_args_list', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ids_of_slide_nodes_with_depth_changes', full_name='KN.CommandShowRemoveSlideArchive.ids_of_slide_nodes_with_depth_changes', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='depths_of_slide_nodes_with_depth_changes', full_name='KN.CommandShowRemoveSlideArchive.depths_of_slide_nodes_with_depth_changes', index=4,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_depths_of_slide_nodes_with_depth_changes', full_name='KN.CommandShowRemoveSlideArchive.old_depths_of_slide_nodes_with_depth_changes', index=5,
      number=6, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_nodes_for_depth_fix_up', full_name='KN.CommandShowRemoveSlideArchive.slide_nodes_for_depth_fix_up', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='depths_of_slide_nodes_for_depth_fix_up', full_name='KN.CommandShowRemoveSlideArchive.depths_of_slide_nodes_for_depth_fix_up', index=7,
      number=8, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_depths_of_slide_nodes_for_depth_fix_up', full_name='KN.CommandShowRemoveSlideArchive.old_depths_of_slide_nodes_for_depth_fix_up', index=8,
      number=9, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collapsed_state_of_slide_nodes_being_removed', full_name='KN.CommandShowRemoveSlideArchive.collapsed_state_of_slide_nodes_being_removed', index=9,
      number=11, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6001,
  serialized_end=6544,
)


_COMMANDSHOWCHANGETHEMEARCHIVE_IDENTIFIERTOSTYLEMAP = _descriptor.Descriptor(
  name='IdentifierToStyleMap',
  full_name='KN.CommandShowChangeThemeArchive.IdentifierToStyleMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='styles', full_name='KN.CommandShowChangeThemeArchive.IdentifierToStyleMap.styles', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6956,
  serialized_end=7039,
)

_COMMANDSHOWCHANGETHEMEARCHIVE = _descriptor.Descriptor(
  name='CommandShowChangeThemeArchive',
  full_name='KN.CommandShowChangeThemeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandShowChangeThemeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show', full_name='KN.CommandShowChangeThemeArchive.show', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='theme', full_name='KN.CommandShowChangeThemeArchive.theme', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_theme', full_name='KN.CommandShowChangeThemeArchive.old_theme', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='template_identifier', full_name='KN.CommandShowChangeThemeArchive.template_identifier', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_template_identifier', full_name='KN.CommandShowChangeThemeArchive.old_template_identifier', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifier_to_style_map', full_name='KN.CommandShowChangeThemeArchive.identifier_to_style_map', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_identifier_to_style_map', full_name='KN.CommandShowChangeThemeArchive.old_identifier_to_style_map', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_COMMANDSHOWCHANGETHEMEARCHIVE_IDENTIFIERTOSTYLEMAP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6547,
  serialized_end=7039,
)


_COMMANDSHOWCHANGESLIDESIZEARCHIVE = _descriptor.Descriptor(
  name='CommandShowChangeSlideSizeArchive',
  full_name='KN.CommandShowChangeSlideSizeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandShowChangeSlideSizeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='KN.CommandShowChangeSlideSizeArchive.size', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7041,
  serialized_end=7137,
)


_COMMANDSETTHEMECUSTOMEFFECTTIMINGCURVEARCHIVE = _descriptor.Descriptor(
  name='CommandSetThemeCustomEffectTimingCurveArchive',
  full_name='KN.CommandSetThemeCustomEffectTimingCurveArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandSetThemeCustomEffectTimingCurveArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='KN.CommandSetThemeCustomEffectTimingCurveArchive.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path_source', full_name='KN.CommandSetThemeCustomEffectTimingCurveArchive.path_source', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_path_source', full_name='KN.CommandSetThemeCustomEffectTimingCurveArchive.old_path_source', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7140,
  serialized_end=7331,
)


_COMMANDMOVEMASTERSARCHIVE = _descriptor.Descriptor(
  name='CommandMoveMastersArchive',
  full_name='KN.CommandMoveMastersArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandMoveMastersArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master_slides', full_name='KN.CommandMoveMastersArchive.master_slides', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_indexes_keys', full_name='KN.CommandMoveMastersArchive.previous_indexes_keys', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_indexes_values', full_name='KN.CommandMoveMastersArchive.previous_indexes_values', index=3,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_master_arrangement', full_name='KN.CommandMoveMastersArchive.final_master_arrangement', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7334,
  serialized_end=7590,
)


_COMMANDINSERTMASTERARCHIVE = _descriptor.Descriptor(
  name='CommandInsertMasterArchive',
  full_name='KN.CommandInsertMasterArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandInsertMasterArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_master_change_commands', full_name='KN.CommandInsertMasterArchive.undo_master_change_commands', index=1,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set_inserted_slide_as_default_master_slide', full_name='KN.CommandInsertMasterArchive.set_inserted_slide_as_default_master_slide', index=2,
      number=8, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_replacement_master_slide_node', full_name='KN.CommandInsertMasterArchive.undo_replacement_master_slide_node', index=3,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7593,
  serialized_end=7822,
)


_COMMANDPRIMITIVEINSERTMASTERARCHIVE = _descriptor.Descriptor(
  name='CommandPrimitiveInsertMasterArchive',
  full_name='KN.CommandPrimitiveInsertMasterArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandPrimitiveInsertMasterArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='was_inserted_with_drop', full_name='KN.CommandPrimitiveInsertMasterArchive.was_inserted_with_drop', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_format_keys', full_name='KN.CommandPrimitiveInsertMasterArchive.custom_format_keys', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_classic_theme_records', full_name='KN.CommandPrimitiveInsertMasterArchive.previous_classic_theme_records', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7825,
  serialized_end=8048,
)


_COMMANDREMOVEMASTERARCHIVE = _descriptor.Descriptor(
  name='CommandRemoveMasterArchive',
  full_name='KN.CommandRemoveMasterArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandRemoveMasterArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replacement_master_slide_node', full_name='KN.CommandRemoveMasterArchive.replacement_master_slide_node', index=1,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master_change_commands', full_name='KN.CommandRemoveMasterArchive.master_change_commands', index=2,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_master_slide_node_was_replaced', full_name='KN.CommandRemoveMasterArchive.default_master_slide_node_was_replaced', index=3,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8051,
  serialized_end=8266,
)


_COMMANDPRIMITIVEREMOVEMASTERARCHIVE = _descriptor.Descriptor(
  name='CommandPrimitiveRemoveMasterArchive',
  full_name='KN.CommandPrimitiveRemoveMasterArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandPrimitiveRemoveMasterArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_classic_theme_records', full_name='KN.CommandPrimitiveRemoveMasterArchive.previous_classic_theme_records', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8269,
  serialized_end=8421,
)


_COMMANDSLIDEINSERTBUILDARCHIVE = _descriptor.Descriptor(
  name='CommandSlideInsertBuildArchive',
  full_name='KN.CommandSlideInsertBuildArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandSlideInsertBuildArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='insert_build_description', full_name='KN.CommandSlideInsertBuildArchive.insert_build_description', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifier_for_chunk_to_insert_after', full_name='KN.CommandSlideInsertBuildArchive.identifier_for_chunk_to_insert_after', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='should_create_chunks', full_name='KN.CommandSlideInsertBuildArchive.should_create_chunks', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_tuples_to_update', full_name='KN.CommandSlideInsertBuildArchive.old_tuples_to_update', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='was_initialized_over_the_wire', full_name='KN.CommandSlideInsertBuildArchive.was_initialized_over_the_wire', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='has_been_committed', full_name='KN.CommandSlideInsertBuildArchive.has_been_committed', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8424,
  serialized_end=8764,
)


_INSERTBUILDDESCRIPTIONARCHIVE = _descriptor.Descriptor(
  name='InsertBuildDescriptionArchive',
  full_name='KN.InsertBuildDescriptionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slide_id', full_name='KN.InsertBuildDescriptionArchive.slide_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='build_to_insert', full_name='KN.InsertBuildDescriptionArchive.build_to_insert', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chunks_to_insert', full_name='KN.InsertBuildDescriptionArchive.chunks_to_insert', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='should_assign_chunk_identifiers', full_name='KN.InsertBuildDescriptionArchive.should_assign_chunk_identifiers', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifers_for_chunks_to_insert_after', full_name='KN.InsertBuildDescriptionArchive.identifers_for_chunks_to_insert_after', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tuples_to_update', full_name='KN.InsertBuildDescriptionArchive.tuples_to_update', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fallback_chunk_identifiers', full_name='KN.InsertBuildDescriptionArchive.fallback_chunk_identifiers', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_for_paste', full_name='KN.InsertBuildDescriptionArchive.is_for_paste', index=7,
      number=8, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8767,
  serialized_end=9164,
)


_UNDOOBJECTARCHIVE = _descriptor.Descriptor(
  name='UndoObjectArchive',
  full_name='KN.UndoObjectArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.UndoObjectArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9166,
  serialized_end=9224,
)


_COMMANDSLIDEREMOVEBUILDARCHIVE = _descriptor.Descriptor(
  name='CommandSlideRemoveBuildArchive',
  full_name='KN.CommandSlideRemoveBuildArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandSlideRemoveBuildArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove_build_description', full_name='KN.CommandSlideRemoveBuildArchive.remove_build_description', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='build', full_name='KN.CommandSlideRemoveBuildArchive.build', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chunks_to_insert', full_name='KN.CommandSlideRemoveBuildArchive.chunks_to_insert', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifiers_for_chunks_to_insert_after', full_name='KN.CommandSlideRemoveBuildArchive.identifiers_for_chunks_to_insert_after', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_tuples_to_update', full_name='KN.CommandSlideRemoveBuildArchive.old_tuples_to_update', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fallback_chunk_identifiers', full_name='KN.CommandSlideRemoveBuildArchive.fallback_chunk_identifiers', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9227,
  serialized_end=9614,
)


_REMOVEBUILDDESCRIPTIONARCHIVE = _descriptor.Descriptor(
  name='RemoveBuildDescriptionArchive',
  full_name='KN.RemoveBuildDescriptionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slide_id', full_name='KN.RemoveBuildDescriptionArchive.slide_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='build_id', full_name='KN.RemoveBuildDescriptionArchive.build_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='should_remove_chunks', full_name='KN.RemoveBuildDescriptionArchive.should_remove_chunks', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='should_remove_chunk_identifiers', full_name='KN.RemoveBuildDescriptionArchive.should_remove_chunk_identifiers', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tuples_to_update', full_name='KN.RemoveBuildDescriptionArchive.tuples_to_update', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9617,
  serialized_end=9819,
)


_COMMANDSLIDEINSERTBUILDCHUNKARCHIVE = _descriptor.Descriptor(
  name='CommandSlideInsertBuildChunkArchive',
  full_name='KN.CommandSlideInsertBuildChunkArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandSlideInsertBuildChunkArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_id', full_name='KN.CommandSlideInsertBuildChunkArchive.slide_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chunk_to_insert', full_name='KN.CommandSlideInsertBuildChunkArchive.chunk_to_insert', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifier_for_chunk_to_insert_after', full_name='KN.CommandSlideInsertBuildChunkArchive.identifier_for_chunk_to_insert_after', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tuples_to_update', full_name='KN.CommandSlideInsertBuildChunkArchive.tuples_to_update', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_tuples_to_update', full_name='KN.CommandSlideInsertBuildChunkArchive.old_tuples_to_update', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='needs_selection_update', full_name='KN.CommandSlideInsertBuildChunkArchive.needs_selection_update', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='should_assign_chunk_identifier', full_name='KN.CommandSlideInsertBuildChunkArchive.should_assign_chunk_identifier', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9822,
  serialized_end=10204,
)


_COMMANDSLIDEREMOVEBUILDCHUNKARCHIVE = _descriptor.Descriptor(
  name='CommandSlideRemoveBuildChunkArchive',
  full_name='KN.CommandSlideRemoveBuildChunkArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandSlideRemoveBuildChunkArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_id', full_name='KN.CommandSlideRemoveBuildChunkArchive.slide_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='removed_chunk', full_name='KN.CommandSlideRemoveBuildChunkArchive.removed_chunk', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifier_for_chunk_to_remove', full_name='KN.CommandSlideRemoveBuildChunkArchive.identifier_for_chunk_to_remove', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifier_for_chunk_to_insert_after', full_name='KN.CommandSlideRemoveBuildChunkArchive.identifier_for_chunk_to_insert_after', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tuples_to_update', full_name='KN.CommandSlideRemoveBuildChunkArchive.tuples_to_update', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_tuples_to_update', full_name='KN.CommandSlideRemoveBuildChunkArchive.old_tuples_to_update', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='needs_selection_update', full_name='KN.CommandSlideRemoveBuildChunkArchive.needs_selection_update', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10207,
  serialized_end=10620,
)


_COMMANDSLIDEMOVEBUILDCHUNKSARCHIVE = _descriptor.Descriptor(
  name='CommandSlideMoveBuildChunksArchive',
  full_name='KN.CommandSlideMoveBuildChunksArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandSlideMoveBuildChunksArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifiers_for_chunks_to_move', full_name='KN.CommandSlideMoveBuildChunksArchive.identifiers_for_chunks_to_move', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifiers_for_chunks_to_move_after', full_name='KN.CommandSlideMoveBuildChunksArchive.identifiers_for_chunks_to_move_after', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifiers_for_chunks_to_move_after_for_undo', full_name='KN.CommandSlideMoveBuildChunksArchive.identifiers_for_chunks_to_move_after_for_undo', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tuples_to_update', full_name='KN.CommandSlideMoveBuildChunksArchive.tuples_to_update', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_tuples_to_update', full_name='KN.CommandSlideMoveBuildChunksArchive.old_tuples_to_update', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifiers_for_chunks_to_move_including_clustered_inactive_chunks', full_name='KN.CommandSlideMoveBuildChunksArchive.identifiers_for_chunks_to_move_including_clustered_inactive_chunks', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10623,
  serialized_end=11132,
)


_COMMANDBUILDSETVALUEARCHIVE = _descriptor.Descriptor(
  name='CommandBuildSetValueArchive',
  full_name='KN.CommandBuildSetValueArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandBuildSetValueArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tuple', full_name='KN.CommandBuildSetValueArchive.tuple', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chunks_to_add', full_name='KN.CommandBuildSetValueArchive.chunks_to_add', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifiers_for_chunks_to_insert_after', full_name='KN.CommandBuildSetValueArchive.identifiers_for_chunks_to_insert_after', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifiers_for_chunks_to_remove', full_name='KN.CommandBuildSetValueArchive.identifiers_for_chunks_to_remove', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tuples_to_update', full_name='KN.CommandBuildSetValueArchive.tuples_to_update', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_tuple_for_main_property', full_name='KN.CommandBuildSetValueArchive.old_tuple_for_main_property', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_tuples_to_update_for_sub_commands', full_name='KN.CommandBuildSetValueArchive.old_tuples_to_update_for_sub_commands', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifiers_for_added_chunks', full_name='KN.CommandBuildSetValueArchive.identifiers_for_added_chunks', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='generated_identifiers', full_name='KN.CommandBuildSetValueArchive.generated_identifiers', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='removed_chunks', full_name='KN.CommandBuildSetValueArchive.removed_chunks', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifiers_for_chunks_prior_to_removed_chunks', full_name='KN.CommandBuildSetValueArchive.identifiers_for_chunks_prior_to_removed_chunks', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_chunk_ID_seed', full_name='KN.CommandBuildSetValueArchive.old_chunk_ID_seed', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_chunk_identifiers', full_name='KN.CommandBuildSetValueArchive.old_chunk_identifiers', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chunks_removed_during_undo', full_name='KN.CommandBuildSetValueArchive.chunks_removed_during_undo', index=14,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11135,
  serialized_end=11991,
)


_COMMANDBUILDUPDATECHUNKREFERENTSARCHIVE = _descriptor.Descriptor(
  name='CommandBuildUpdateChunkReferentsArchive',
  full_name='KN.CommandBuildUpdateChunkReferentsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandBuildUpdateChunkReferentsArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='build_id', full_name='KN.CommandBuildUpdateChunkReferentsArchive.build_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tuples_to_update', full_name='KN.CommandBuildUpdateChunkReferentsArchive.tuples_to_update', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_tuples_to_update', full_name='KN.CommandBuildUpdateChunkReferentsArchive.old_tuples_to_update', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11994,
  serialized_end=12188,
)


_COMMANDBUILDUPDATECHUNKCOUNTARCHIVE = _descriptor.Descriptor(
  name='CommandBuildUpdateChunkCountArchive',
  full_name='KN.CommandBuildUpdateChunkCountArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandBuildUpdateChunkCountArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_id', full_name='KN.CommandBuildUpdateChunkCountArchive.slide_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drawable_ids', full_name='KN.CommandBuildUpdateChunkCountArchive.drawable_ids', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expected_delivery_style_tuples', full_name='KN.CommandBuildUpdateChunkCountArchive.expected_delivery_style_tuples', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chunks_to_add', full_name='KN.CommandBuildUpdateChunkCountArchive.chunks_to_add', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifiers_for_chunks_to_insert_after', full_name='KN.CommandBuildUpdateChunkCountArchive.identifiers_for_chunks_to_insert_after', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifiers_for_chunks_to_remove', full_name='KN.CommandBuildUpdateChunkCountArchive.identifiers_for_chunks_to_remove', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tuples_to_update', full_name='KN.CommandBuildUpdateChunkCountArchive.tuples_to_update', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='needs_async_process_changes_selection_update', full_name='KN.CommandBuildUpdateChunkCountArchive.needs_async_process_changes_selection_update', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_tuples_to_update', full_name='KN.CommandBuildUpdateChunkCountArchive.old_tuples_to_update', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifiers_for_added_chunks', full_name='KN.CommandBuildUpdateChunkCountArchive.identifiers_for_added_chunks', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='generated_identifiers', full_name='KN.CommandBuildUpdateChunkCountArchive.generated_identifiers', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='removed_chunks', full_name='KN.CommandBuildUpdateChunkCountArchive.removed_chunks', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifiers_for_chunks_prior_to_removed_chunks', full_name='KN.CommandBuildUpdateChunkCountArchive.identifiers_for_chunks_prior_to_removed_chunks', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_delivery_style_tuples', full_name='KN.CommandBuildUpdateChunkCountArchive.old_delivery_style_tuples', index=14,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_chunk_ID_seeds', full_name='KN.CommandBuildUpdateChunkCountArchive.old_chunk_ID_seeds', index=15,
      number=16, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_chunk_identifiers', full_name='KN.CommandBuildUpdateChunkCountArchive.old_chunk_identifiers', index=16,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='working_builds', full_name='KN.CommandBuildUpdateChunkCountArchive.working_builds', index=17,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chunks_removed_during_undo', full_name='KN.CommandBuildUpdateChunkCountArchive.chunks_removed_during_undo', index=18,
      number=19, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chunks_added_during_undo', full_name='KN.CommandBuildUpdateChunkCountArchive.chunks_added_during_undo', index=19,
      number=20, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12191,
  serialized_end=13268,
)


_COMMANDBUILDCHUNKSETVALUEARCHIVE = _descriptor.Descriptor(
  name='CommandBuildChunkSetValueArchive',
  full_name='KN.CommandBuildChunkSetValueArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandBuildChunkSetValueArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tuples_to_update', full_name='KN.CommandBuildChunkSetValueArchive.tuples_to_update', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_tuples_to_update', full_name='KN.CommandBuildChunkSetValueArchive.old_tuples_to_update', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13271,
  serialized_end=13429,
)


_COMMANDTRANSITIONSETVALUEARCHIVE = _descriptor.Descriptor(
  name='CommandTransitionSetValueArchive',
  full_name='KN.CommandTransitionSetValueArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandTransitionSetValueArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_node_id_path', full_name='KN.CommandTransitionSetValueArchive.slide_node_id_path', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_attributes', full_name='KN.CommandTransitionSetValueArchive.old_attributes', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='KN.CommandTransitionSetValueArchive.attributes', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='property', full_name='KN.CommandTransitionSetValueArchive.property', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13432,
  serialized_end=13673,
)


_COMMANDSHOWSETSLIDENUMBERVISIBILITYARCHIVE = _descriptor.Descriptor(
  name='CommandShowSetSlideNumberVisibilityArchive',
  full_name='KN.CommandShowSetSlideNumberVisibilityArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandShowSetSlideNumberVisibilityArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_numbers_visible', full_name='KN.CommandShowSetSlideNumberVisibilityArchive.slide_numbers_visible', index=1,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ids_of_slide_nodes_to_skip', full_name='KN.CommandShowSetSlideNumberVisibilityArchive.ids_of_slide_nodes_to_skip', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ids_of_slide_nodes_already_correct', full_name='KN.CommandShowSetSlideNumberVisibilityArchive.ids_of_slide_nodes_already_correct', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_undo', full_name='KN.CommandShowSetSlideNumberVisibilityArchive.is_undo', index=4,
      number=6, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13676,
  serialized_end=13906,
)


_COMMANDMASTERSETTHUMBNAILTEXTARCHIVE = _descriptor.Descriptor(
  name='CommandMasterSetThumbnailTextArchive',
  full_name='KN.CommandMasterSetThumbnailTextArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandMasterSetThumbnailTextArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master_id', full_name='KN.CommandMasterSetThumbnailTextArchive.master_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_body', full_name='KN.CommandMasterSetThumbnailTextArchive.is_body', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_text', full_name='KN.CommandMasterSetThumbnailTextArchive.new_text', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_text', full_name='KN.CommandMasterSetThumbnailTextArchive.old_text', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13909,
  serialized_end=14066,
)


_COMMANDMASTERSETBODYSTYLESARCHIVE = _descriptor.Descriptor(
  name='CommandMasterSetBodyStylesArchive',
  full_name='KN.CommandMasterSetBodyStylesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandMasterSetBodyStylesArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master_id', full_name='KN.CommandMasterSetBodyStylesArchive.master_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_paragraph_styles', full_name='KN.CommandMasterSetBodyStylesArchive.new_paragraph_styles', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_list_styles', full_name='KN.CommandMasterSetBodyStylesArchive.new_list_styles', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_paragraph_styles', full_name='KN.CommandMasterSetBodyStylesArchive.old_paragraph_styles', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_list_styles', full_name='KN.CommandMasterSetBodyStylesArchive.old_list_styles', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14069,
  serialized_end=14344,
)


_COMMANDCHANGEMASTERSLIDEARCHIVE = _descriptor.Descriptor(
  name='CommandChangeMasterSlideArchive',
  full_name='KN.CommandChangeMasterSlideArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandChangeMasterSlideArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_id_path', full_name='KN.CommandChangeMasterSlideArchive.slide_id_path', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master_node', full_name='KN.CommandChangeMasterSlideArchive.master_node', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_master_node', full_name='KN.CommandChangeMasterSlideArchive.old_master_node', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_undo_redo', full_name='KN.CommandChangeMasterSlideArchive.is_undo_redo', index=4,
      number=5, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_prototype', full_name='KN.CommandChangeMasterSlideArchive.target_prototype', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14347,
  serialized_end=14596,
)


_COMMANDSLIDEPRIMITIVESETMASTERARCHIVE = _descriptor.Descriptor(
  name='CommandSlidePrimitiveSetMasterArchive',
  full_name='KN.CommandSlidePrimitiveSetMasterArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandSlidePrimitiveSetMasterArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_id_path', full_name='KN.CommandSlidePrimitiveSetMasterArchive.slide_id_path', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master_id', full_name='KN.CommandSlidePrimitiveSetMasterArchive.master_id', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_master_node', full_name='KN.CommandSlidePrimitiveSetMasterArchive.old_master_node', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14599,
  serialized_end=14783,
)


_COMMANDSLIDERESETMASTERBACKGROUNDOBJECTSARCHIVE = _descriptor.Descriptor(
  name='CommandSlideResetMasterBackgroundObjectsArchive',
  full_name='KN.CommandSlideResetMasterBackgroundObjectsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandSlideResetMasterBackgroundObjectsArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_id_path', full_name='KN.CommandSlideResetMasterBackgroundObjectsArchive.slide_id_path', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14785,
  serialized_end=14908,
)


_COMMANDSHOWSETSOUNDTRACK = _descriptor.Descriptor(
  name='CommandShowSetSoundtrack',
  full_name='KN.CommandShowSetSoundtrack',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandShowSetSoundtrack.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show', full_name='KN.CommandShowSetSoundtrack.show', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='soundtrack', full_name='KN.CommandShowSetSoundtrack.soundtrack', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_soundtrack', full_name='KN.CommandShowSetSoundtrack.old_soundtrack', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14911,
  serialized_end=15079,
)


_COMMANDSOUNDTRACKSETVALUE_PROPERTYVALUE = _descriptor.Descriptor(
  name='PropertyValue',
  full_name='KN.CommandSoundtrackSetValue.PropertyValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='double_value', full_name='KN.CommandSoundtrackSetValue.PropertyValue.double_value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mode_value', full_name='KN.CommandSoundtrackSetValue.PropertyValue.mode_value', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='media_reference_values', full_name='KN.CommandSoundtrackSetValue.PropertyValue.media_reference_values', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15328,
  serialized_end=15468,
)

_COMMANDSOUNDTRACKSETVALUE = _descriptor.Descriptor(
  name='CommandSoundtrackSetValue',
  full_name='KN.CommandSoundtrackSetValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandSoundtrackSetValue.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='soundtrack_id', full_name='KN.CommandSoundtrackSetValue.soundtrack_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='property', full_name='KN.CommandSoundtrackSetValue.property', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_value', full_name='KN.CommandSoundtrackSetValue.old_value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_value', full_name='KN.CommandSoundtrackSetValue.new_value', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_COMMANDSOUNDTRACKSETVALUE_PROPERTYVALUE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15082,
  serialized_end=15468,
)


_COMMANDSLIDEUPDATEMASTERDRAWABLES = _descriptor.Descriptor(
  name='CommandSlideUpdateMasterDrawables',
  full_name='KN.CommandSlideUpdateMasterDrawables',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandSlideUpdateMasterDrawables.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_id', full_name='KN.CommandSlideUpdateMasterDrawables.slide_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id_placement_operation_args', full_name='KN.CommandSlideUpdateMasterDrawables.id_placement_operation_args', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_child_infos_for_undo', full_name='KN.CommandSlideUpdateMasterDrawables.old_child_infos_for_undo', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15471,
  serialized_end=15689,
)


_CHARTINFOGEOMETRYCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ChartInfoGeometryCommandArchive',
  full_name='KN.ChartInfoGeometryCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.ChartInfoGeometryCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_legend_offset', full_name='KN.ChartInfoGeometryCommandArchive.previous_legend_offset', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_legend_size', full_name='KN.ChartInfoGeometryCommandArchive.previous_legend_size', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='adjusted_legend_offset', full_name='KN.ChartInfoGeometryCommandArchive.adjusted_legend_offset', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='adjusted_legend_size', full_name='KN.ChartInfoGeometryCommandArchive.adjusted_legend_size', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15692,
  serialized_end=15943,
)


_CANVASSELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='CanvasSelectionTransformerArchive',
  full_name='KN.CanvasSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transformer_helper', full_name='KN.CanvasSelectionTransformerArchive.transformer_helper', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='build_chunk_ids', full_name='KN.CanvasSelectionTransformerArchive.build_chunk_ids', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action_build_ids', full_name='KN.CanvasSelectionTransformerArchive.action_build_ids', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='originally_selected_drawable_uuids', full_name='KN.CanvasSelectionTransformerArchive.originally_selected_drawable_uuids', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15946,
  serialized_end=16213,
)


_ACTIONGHOSTSELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='ActionGhostSelectionTransformerArchive',
  full_name='KN.ActionGhostSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16215,
  serialized_end=16255,
)


_DOCUMENTSELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='DocumentSelectionTransformerArchive',
  full_name='KN.DocumentSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='document_selection', full_name='KN.DocumentSelectionTransformerArchive.document_selection', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16257,
  serialized_end=16338,
)


_NOTECANVASSELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='NoteCanvasSelectionTransformerArchive',
  full_name='KN.NoteCanvasSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transformer_helper', full_name='KN.NoteCanvasSelectionTransformerArchive.transformer_helper', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16340,
  serialized_end=16461,
)


_OUTLINECANVASSELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='OutlineCanvasSelectionTransformerArchive',
  full_name='KN.OutlineCanvasSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='canvas_selection_transformer', full_name='KN.OutlineCanvasSelectionTransformerArchive.canvas_selection_transformer', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage_uuid_path', full_name='KN.OutlineCanvasSelectionTransformerArchive.storage_uuid_path', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16464,
  serialized_end=16602,
)


_SLIDECOLLECTIONSELECTIONTRANSFORMERHELPERARCHIVE = _descriptor.Descriptor(
  name='SlideCollectionSelectionTransformerHelperArchive',
  full_name='KN.SlideCollectionSelectionTransformerHelperArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slide_nodes', full_name='KN.SlideCollectionSelectionTransformerHelperArchive.slide_nodes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_node_to_edit', full_name='KN.SlideCollectionSelectionTransformerHelperArchive.slide_node_to_edit', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_collection_is_theme', full_name='KN.SlideCollectionSelectionTransformerHelperArchive.slide_collection_is_theme', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_primary_selected_index', full_name='KN.SlideCollectionSelectionTransformerHelperArchive.previous_primary_selected_index', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16605,
  serialized_end=16810,
)


_SLIDECOLLECTIONSELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='SlideCollectionSelectionTransformerArchive',
  full_name='KN.SlideCollectionSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transformer_helper', full_name='KN.SlideCollectionSelectionTransformerArchive.transformer_helper', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16812,
  serialized_end=16938,
)


_OUTLINESELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='OutlineSelectionTransformerArchive',
  full_name='KN.OutlineSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transformer_helper', full_name='KN.OutlineSelectionTransformerArchive.transformer_helper', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='can_have_range_in_selected_paragraph', full_name='KN.OutlineSelectionTransformerArchive.can_have_range_in_selected_paragraph', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selection_range_addresses', full_name='KN.OutlineSelectionTransformerArchive.selection_range_addresses', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16941,
  serialized_end=17159,
)

_UISTATECOMMANDGROUPARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDGROUPARCHIVE
_UISTATECOMMANDGROUPARCHIVE.fields_by_name['uiState'].message_type = TSPMessages__pb2._REFERENCE
_UISTATECOMMANDGROUPARCHIVE.fields_by_name['slideNodesToEdit'].message_type = TSPMessages__pb2._REFERENCE
_UISTATECOMMANDGROUPARCHIVE.fields_by_name['masterSlideNodesToApply'].message_type = TSPMessages__pb2._REFERENCE
_UISTATECOMMANDGROUPARCHIVE.fields_by_name['thumbnailSizes'].message_type = TSPMessages__pb2._SIZE
_UISTATECOMMANDGROUPARCHIVE.fields_by_name['selectedSlideNodes'].message_type = TSPMessages__pb2._REFERENCE
_UISTATECOMMANDGROUPARCHIVE.fields_by_name['restoreSelectedSlideNodes'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDEINSERTDRAWABLESARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSLIDEINSERTDRAWABLESARCHIVE.fields_by_name['slide_id'].message_type = TSPMessages__pb2._UUID
_COMMANDSLIDEINSERTDRAWABLESARCHIVE.fields_by_name['drawables'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDEINSERTDRAWABLESARCHIVE.fields_by_name['working_drawables'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDEINSERTDRAWABLESARCHIVE.fields_by_name['args_list'].message_type = KNArchives__pb2._MIXEDIDOPERATIONARGS
_COMMANDSLIDEINSERTDRAWABLESARCHIVE.fields_by_name['ids_of_drawables_using_object_placeholder_geometry'].message_type = TSPMessages__pb2._UUID
_COMMANDSLIDEINSERTDRAWABLESARCHIVE.fields_by_name['undo_archive'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDEINSERTDRAWABLESARCHIVE.fields_by_name['insert_build_descriptions'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDEINSERTDRAWABLESARCHIVE.fields_by_name['working_insert_build_descriptions'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDEINSERTDRAWABLESARCHIVE.fields_by_name['remove_build_descriptions'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDEINSERTDRAWABLESARCHIVE.fields_by_name['custom_format_keys'].message_type = TSPMessages__pb2._UUID
_COMMANDSLIDEINSERTDRAWABLESARCHIVE.fields_by_name['geometry_of_object_placeholder_for_comparison_to_restore_link'].message_type = TSDArchives__pb2._GEOMETRYARCHIVE
_COMMANDSLIDESETPLACEHOLDERSFORTAGSARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSLIDESETPLACEHOLDERSFORTAGSARCHIVE.fields_by_name['slide_id'].message_type = TSPMessages__pb2._UUID
_COMMANDSLIDESETPLACEHOLDERSFORTAGSARCHIVE.fields_by_name['infos'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDESETPLACEHOLDERSFORTAGSARCHIVE.fields_by_name['old_infos'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDMASTERSLIDESETPLACEHOLDERFORTAGARCHIVE.fields_by_name['super'].message_type = _COMMANDSLIDESETPLACEHOLDERSFORTAGSARCHIVE
_COMMANDMASTERSLIDESETPLACEHOLDERFORTAGARCHIVE.fields_by_name['placeholder_id'].message_type = TSPMessages__pb2._UUID
_COMMANDSLIDEPROPAGATESETPLACEHOLDERFORTAGARCHIVE.fields_by_name['super'].message_type = _COMMANDSLIDESETPLACEHOLDERSFORTAGSARCHIVE
_COMMANDSLIDEPROPAGATESETPLACEHOLDERFORTAGARCHIVE.fields_by_name['placeholder_id'].message_type = TSPMessages__pb2._UUID
_COMMANDSLIDEPROPAGATESETPLACEHOLDERFORTAGARCHIVE.fields_by_name['original_id'].message_type = TSPMessages__pb2._UUID
_COMMANDSLIDEREMOVEDRAWABLEARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSLIDEREMOVEDRAWABLEARCHIVE.fields_by_name['slide_id'].message_type = TSPMessages__pb2._UUID
_COMMANDSLIDEREMOVEDRAWABLEARCHIVE.fields_by_name['sortedDrawables'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDEREMOVEDRAWABLEARCHIVE.fields_by_name['args_list'].message_type = KNArchives__pb2._MIXEDIDOPERATIONARGS
_COMMANDSLIDEREMOVEDRAWABLEARCHIVE.fields_by_name['insert_build_descriptions'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDEREMOVEDRAWABLEARCHIVE.fields_by_name['remove_build_descriptions'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDEREMOVEDRAWABLEARCHIVE.fields_by_name['drawables_using_object_placeholder_geometry'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDEREMOVEDRAWABLEARCHIVE.fields_by_name['inverse_insert_hyperlink_commands'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDEMOVEDRAWABLEZORDERARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSLIDEMOVEDRAWABLEZORDERARCHIVE.fields_by_name['old_ordered_infos'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDEMOVEDRAWABLEZORDERARCHIVE.fields_by_name['args_list'].message_type = TSKArchives__pb2._REARRANGEIDOPERATIONARGS
_COMMANDSLIDEMOVEDRAWABLEZORDERARCHIVE.fields_by_name['slide_id'].message_type = TSPMessages__pb2._UUID
_COMMANDSLIDEMOVEDRAWABLEZORDERARCHIVE.fields_by_name['old_ordered_infos_on_slide_for_undo'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDENODESETPROPERTYARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSLIDENODESETPROPERTYARCHIVE.fields_by_name['slide_node_id_path'].message_type = TSPMessages__pb2._UUIDPATH
_COMMANDSLIDENODESETVIEWSTATEPROPERTYARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSLIDENODESETVIEWSTATEPROPERTYARCHIVE.fields_by_name['slide_node_id_path'].message_type = TSPMessages__pb2._UUIDPATH
_COMMANDSLIDESETBACKGROUNDFILLARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSLIDESETBACKGROUNDFILLARCHIVE.fields_by_name['slide_id_path'].message_type = TSPMessages__pb2._UUIDPATH
_COMMANDSLIDESETBACKGROUNDFILLARCHIVE.fields_by_name['old_fill'].message_type = TSDArchives__pb2._FILLARCHIVE
_COMMANDSLIDESETBACKGROUNDFILLARCHIVE.fields_by_name['new_fill'].message_type = TSDArchives__pb2._FILLARCHIVE
_COMMANDSLIDESETSTYLEARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSLIDESETSTYLEARCHIVE.fields_by_name['slide_id_path'].message_type = TSPMessages__pb2._UUIDPATH
_COMMANDSLIDESETSTYLEARCHIVE.fields_by_name['slide_style'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDESETSTYLEARCHIVE.fields_by_name['old_slide_style'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSHOWMARKOUTOFSYNCRECORDINGARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSHOWMARKOUTOFSYNCRECORDINGARCHIVE.fields_by_name['show'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSHOWMARKOUTOFSYNCRECORDINGARCHIVE.fields_by_name['old_recording'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSHOWMARKOUTOFSYNCRECORDINGARCHIVE.fields_by_name['old_modification_date'].message_type = TSPMessages__pb2._DATE
_COMMANDSHOWMARKOUTOFSYNCRECORDINGARCHIVE.fields_by_name['new_modification_date'].message_type = TSPMessages__pb2._DATE
_COMMANDSHOWMARKOUTOFSYNCRECORDINGIFNEEDEDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSHOWMARKOUTOFSYNCRECORDINGIFNEEDEDARCHIVE.fields_by_name['out_of_sync_token'].message_type = TSPMessages__pb2._UUID
_COMMANDSHOWREMOVERECORDINGARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSHOWREMOVERECORDINGARCHIVE.fields_by_name['show'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSHOWREMOVERECORDINGARCHIVE.fields_by_name['old_recording'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSHOWREPLACERECORDINGARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSHOWREPLACERECORDINGARCHIVE.fields_by_name['show'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSHOWREPLACERECORDINGARCHIVE.fields_by_name['replacement_recording'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSHOWREPLACERECORDINGARCHIVE.fields_by_name['old_recording'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSHOWSETVALUEARCHIVE_PROPERTYVALUE.fields_by_name['show_mode_value'].enum_type = KNArchives__pb2._SHOWARCHIVE_KNSHOWMODE
_COMMANDSHOWSETVALUEARCHIVE_PROPERTYVALUE.fields_by_name['size_value'].message_type = TSPMessages__pb2._SIZE
_COMMANDSHOWSETVALUEARCHIVE_PROPERTYVALUE.containing_type = _COMMANDSHOWSETVALUEARCHIVE
_COMMANDSHOWSETVALUEARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSHOWSETVALUEARCHIVE.fields_by_name['show'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSHOWSETVALUEARCHIVE.fields_by_name['old_value'].message_type = _COMMANDSHOWSETVALUEARCHIVE_PROPERTYVALUE
_COMMANDSHOWSETVALUEARCHIVE.fields_by_name['new_value'].message_type = _COMMANDSHOWSETVALUEARCHIVE_PROPERTYVALUE
_COMMANDSHOWINSERTSLIDEARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSHOWINSERTSLIDEARCHIVE.fields_by_name['slide_nodes_being_inserted'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSHOWINSERTSLIDEARCHIVE.fields_by_name['working_slide_nodes_being_inserted'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSHOWINSERTSLIDEARCHIVE.fields_by_name['inserted_args_list'].message_type = TSKArchives__pb2._ADDIDOPERATIONARGS
_COMMANDSHOWINSERTSLIDEARCHIVE.fields_by_name['ids_of_slide_nodes_with_depth_changes'].message_type = TSPMessages__pb2._UUID
_COMMANDSHOWINSERTSLIDEARCHIVE.fields_by_name['slide_nodes_for_depth_fix_up'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSHOWINSERTSLIDEARCHIVE.fields_by_name['kind'].enum_type = _COMMANDSHOWINSERTSLIDEARCHIVE_KIND
_COMMANDSHOWINSERTSLIDEARCHIVE.fields_by_name['master_nodes_being_inserted'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSHOWINSERTSLIDEARCHIVE.fields_by_name['custom_format_keys'].message_type = TSPMessages__pb2._UUID
_COMMANDSHOWINSERTSLIDEARCHIVE.fields_by_name['undo_archive'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSHOWINSERTSLIDEARCHIVE_KIND.containing_type = _COMMANDSHOWINSERTSLIDEARCHIVE
_COMMANDSHOWMOVESLIDEARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSHOWMOVESLIDEARCHIVE.fields_by_name['slide_nodes_being_moved_linearly'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSHOWMOVESLIDEARCHIVE.fields_by_name['rearranged_args_list'].message_type = TSKArchives__pb2._REARRANGEIDOPERATIONARGS
_COMMANDSHOWMOVESLIDEARCHIVE.fields_by_name['ids_of_slide_nodes_with_depth_changes'].message_type = TSPMessages__pb2._UUID
_COMMANDSHOWMOVESLIDEARCHIVE.fields_by_name['slide_nodes_for_depth_fix_up'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSHOWREMOVESLIDEARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSHOWREMOVESLIDEARCHIVE.fields_by_name['slide_nodes_being_removed'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSHOWREMOVESLIDEARCHIVE.fields_by_name['removed_args_list'].message_type = TSKArchives__pb2._REMOVEIDOPERATIONARGS
_COMMANDSHOWREMOVESLIDEARCHIVE.fields_by_name['ids_of_slide_nodes_with_depth_changes'].message_type = TSPMessages__pb2._UUID
_COMMANDSHOWREMOVESLIDEARCHIVE.fields_by_name['slide_nodes_for_depth_fix_up'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSHOWCHANGETHEMEARCHIVE_IDENTIFIERTOSTYLEMAP.fields_by_name['styles'].message_type = TSSArchives__pb2._STYLESHEETARCHIVE_IDENTIFIEDSTYLEENTRY
_COMMANDSHOWCHANGETHEMEARCHIVE_IDENTIFIERTOSTYLEMAP.containing_type = _COMMANDSHOWCHANGETHEMEARCHIVE
_COMMANDSHOWCHANGETHEMEARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSHOWCHANGETHEMEARCHIVE.fields_by_name['show'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSHOWCHANGETHEMEARCHIVE.fields_by_name['theme'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSHOWCHANGETHEMEARCHIVE.fields_by_name['old_theme'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSHOWCHANGETHEMEARCHIVE.fields_by_name['identifier_to_style_map'].message_type = _COMMANDSHOWCHANGETHEMEARCHIVE_IDENTIFIERTOSTYLEMAP
_COMMANDSHOWCHANGETHEMEARCHIVE.fields_by_name['old_identifier_to_style_map'].message_type = _COMMANDSHOWCHANGETHEMEARCHIVE_IDENTIFIERTOSTYLEMAP
_COMMANDSHOWCHANGESLIDESIZEARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSHOWCHANGESLIDESIZEARCHIVE.fields_by_name['size'].message_type = TSPMessages__pb2._SIZE
_COMMANDSETTHEMECUSTOMEFFECTTIMINGCURVEARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSETTHEMECUSTOMEFFECTTIMINGCURVEARCHIVE.fields_by_name['path_source'].message_type = TSDArchives__pb2._PATHSOURCEARCHIVE
_COMMANDSETTHEMECUSTOMEFFECTTIMINGCURVEARCHIVE.fields_by_name['old_path_source'].message_type = TSDArchives__pb2._PATHSOURCEARCHIVE
_COMMANDMOVEMASTERSARCHIVE.fields_by_name['super'].message_type = TSDCommandArchives__pb2._CONTAINERREORDERCHILDRENCOMMANDARCHIVE
_COMMANDMOVEMASTERSARCHIVE.fields_by_name['master_slides'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDMOVEMASTERSARCHIVE.fields_by_name['previous_indexes_keys'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDMOVEMASTERSARCHIVE.fields_by_name['final_master_arrangement'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDINSERTMASTERARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDINSERTMASTERARCHIVE.fields_by_name['undo_master_change_commands'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDINSERTMASTERARCHIVE.fields_by_name['undo_replacement_master_slide_node'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDPRIMITIVEINSERTMASTERARCHIVE.fields_by_name['super'].message_type = TSDCommandArchives__pb2._CONTAINERINSERTCHILDRENCOMMANDARCHIVE
_COMMANDPRIMITIVEINSERTMASTERARCHIVE.fields_by_name['custom_format_keys'].message_type = TSPMessages__pb2._UUID
_COMMANDPRIMITIVEINSERTMASTERARCHIVE.fields_by_name['previous_classic_theme_records'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDREMOVEMASTERARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDREMOVEMASTERARCHIVE.fields_by_name['replacement_master_slide_node'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDREMOVEMASTERARCHIVE.fields_by_name['master_change_commands'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDPRIMITIVEREMOVEMASTERARCHIVE.fields_by_name['super'].message_type = TSDCommandArchives__pb2._CONTAINERREMOVECHILDRENCOMMANDARCHIVE
_COMMANDPRIMITIVEREMOVEMASTERARCHIVE.fields_by_name['previous_classic_theme_records'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDEINSERTBUILDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSLIDEINSERTBUILDARCHIVE.fields_by_name['insert_build_description'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDEINSERTBUILDARCHIVE.fields_by_name['identifier_for_chunk_to_insert_after'].message_type = KNArchives__pb2._BUILDCHUNKIDENTIFIERARCHIVE
_COMMANDSLIDEINSERTBUILDARCHIVE.fields_by_name['old_tuples_to_update'].message_type = TSPMessages__pb2._REFERENCE
_INSERTBUILDDESCRIPTIONARCHIVE.fields_by_name['slide_id'].message_type = TSPMessages__pb2._UUID
_INSERTBUILDDESCRIPTIONARCHIVE.fields_by_name['build_to_insert'].message_type = TSPMessages__pb2._REFERENCE
_INSERTBUILDDESCRIPTIONARCHIVE.fields_by_name['chunks_to_insert'].message_type = TSPMessages__pb2._REFERENCE
_INSERTBUILDDESCRIPTIONARCHIVE.fields_by_name['identifers_for_chunks_to_insert_after'].message_type = KNArchives__pb2._BUILDCHUNKIDENTIFIERARCHIVE
_INSERTBUILDDESCRIPTIONARCHIVE.fields_by_name['tuples_to_update'].message_type = TSPMessages__pb2._REFERENCE
_INSERTBUILDDESCRIPTIONARCHIVE.fields_by_name['fallback_chunk_identifiers'].message_type = KNArchives__pb2._BUILDCHUNKIDENTIFIERARCHIVE
_UNDOOBJECTARCHIVE.fields_by_name['super'].message_type = TSDCommandArchives__pb2._UNDOOBJECTARCHIVE
_COMMANDSLIDEREMOVEBUILDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSLIDEREMOVEBUILDARCHIVE.fields_by_name['remove_build_description'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDEREMOVEBUILDARCHIVE.fields_by_name['build'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDEREMOVEBUILDARCHIVE.fields_by_name['chunks_to_insert'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDEREMOVEBUILDARCHIVE.fields_by_name['identifiers_for_chunks_to_insert_after'].message_type = KNArchives__pb2._BUILDCHUNKIDENTIFIERARCHIVE
_COMMANDSLIDEREMOVEBUILDARCHIVE.fields_by_name['old_tuples_to_update'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDEREMOVEBUILDARCHIVE.fields_by_name['fallback_chunk_identifiers'].message_type = KNArchives__pb2._BUILDCHUNKIDENTIFIERARCHIVE
_REMOVEBUILDDESCRIPTIONARCHIVE.fields_by_name['slide_id'].message_type = TSPMessages__pb2._UUID
_REMOVEBUILDDESCRIPTIONARCHIVE.fields_by_name['build_id'].message_type = TSPMessages__pb2._UUID
_REMOVEBUILDDESCRIPTIONARCHIVE.fields_by_name['tuples_to_update'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDEINSERTBUILDCHUNKARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSLIDEINSERTBUILDCHUNKARCHIVE.fields_by_name['slide_id'].message_type = TSPMessages__pb2._UUID
_COMMANDSLIDEINSERTBUILDCHUNKARCHIVE.fields_by_name['chunk_to_insert'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDEINSERTBUILDCHUNKARCHIVE.fields_by_name['identifier_for_chunk_to_insert_after'].message_type = KNArchives__pb2._BUILDCHUNKIDENTIFIERARCHIVE
_COMMANDSLIDEINSERTBUILDCHUNKARCHIVE.fields_by_name['tuples_to_update'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDEINSERTBUILDCHUNKARCHIVE.fields_by_name['old_tuples_to_update'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDEREMOVEBUILDCHUNKARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSLIDEREMOVEBUILDCHUNKARCHIVE.fields_by_name['slide_id'].message_type = TSPMessages__pb2._UUID
_COMMANDSLIDEREMOVEBUILDCHUNKARCHIVE.fields_by_name['removed_chunk'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDEREMOVEBUILDCHUNKARCHIVE.fields_by_name['identifier_for_chunk_to_remove'].message_type = KNArchives__pb2._BUILDCHUNKIDENTIFIERARCHIVE
_COMMANDSLIDEREMOVEBUILDCHUNKARCHIVE.fields_by_name['identifier_for_chunk_to_insert_after'].message_type = KNArchives__pb2._BUILDCHUNKIDENTIFIERARCHIVE
_COMMANDSLIDEREMOVEBUILDCHUNKARCHIVE.fields_by_name['tuples_to_update'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDEREMOVEBUILDCHUNKARCHIVE.fields_by_name['old_tuples_to_update'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDEMOVEBUILDCHUNKSARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSLIDEMOVEBUILDCHUNKSARCHIVE.fields_by_name['identifiers_for_chunks_to_move'].message_type = KNArchives__pb2._BUILDCHUNKIDENTIFIERARCHIVE
_COMMANDSLIDEMOVEBUILDCHUNKSARCHIVE.fields_by_name['identifiers_for_chunks_to_move_after'].message_type = KNArchives__pb2._BUILDCHUNKIDENTIFIERARCHIVE
_COMMANDSLIDEMOVEBUILDCHUNKSARCHIVE.fields_by_name['identifiers_for_chunks_to_move_after_for_undo'].message_type = KNArchives__pb2._BUILDCHUNKIDENTIFIERARCHIVE
_COMMANDSLIDEMOVEBUILDCHUNKSARCHIVE.fields_by_name['tuples_to_update'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDEMOVEBUILDCHUNKSARCHIVE.fields_by_name['old_tuples_to_update'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDEMOVEBUILDCHUNKSARCHIVE.fields_by_name['identifiers_for_chunks_to_move_including_clustered_inactive_chunks'].message_type = KNArchives__pb2._BUILDCHUNKIDENTIFIERARCHIVE
_COMMANDBUILDSETVALUEARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDBUILDSETVALUEARCHIVE.fields_by_name['tuple'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDBUILDSETVALUEARCHIVE.fields_by_name['chunks_to_add'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDBUILDSETVALUEARCHIVE.fields_by_name['identifiers_for_chunks_to_insert_after'].message_type = KNArchives__pb2._BUILDCHUNKIDENTIFIERARCHIVE
_COMMANDBUILDSETVALUEARCHIVE.fields_by_name['identifiers_for_chunks_to_remove'].message_type = KNArchives__pb2._BUILDCHUNKIDENTIFIERARCHIVE
_COMMANDBUILDSETVALUEARCHIVE.fields_by_name['tuples_to_update'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDBUILDSETVALUEARCHIVE.fields_by_name['old_tuple_for_main_property'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDBUILDSETVALUEARCHIVE.fields_by_name['old_tuples_to_update_for_sub_commands'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDBUILDSETVALUEARCHIVE.fields_by_name['identifiers_for_added_chunks'].message_type = KNArchives__pb2._BUILDCHUNKIDENTIFIERARCHIVE
_COMMANDBUILDSETVALUEARCHIVE.fields_by_name['generated_identifiers'].message_type = KNArchives__pb2._BUILDCHUNKIDENTIFIERARCHIVE
_COMMANDBUILDSETVALUEARCHIVE.fields_by_name['removed_chunks'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDBUILDSETVALUEARCHIVE.fields_by_name['identifiers_for_chunks_prior_to_removed_chunks'].message_type = KNArchives__pb2._BUILDCHUNKIDENTIFIERARCHIVE
_COMMANDBUILDSETVALUEARCHIVE.fields_by_name['old_chunk_identifiers'].message_type = KNArchives__pb2._BUILDCHUNKIDENTIFIERARCHIVE
_COMMANDBUILDSETVALUEARCHIVE.fields_by_name['chunks_removed_during_undo'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDBUILDUPDATECHUNKREFERENTSARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDBUILDUPDATECHUNKREFERENTSARCHIVE.fields_by_name['build_id'].message_type = TSPMessages__pb2._UUID
_COMMANDBUILDUPDATECHUNKREFERENTSARCHIVE.fields_by_name['tuples_to_update'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDBUILDUPDATECHUNKREFERENTSARCHIVE.fields_by_name['old_tuples_to_update'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDBUILDUPDATECHUNKCOUNTARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDBUILDUPDATECHUNKCOUNTARCHIVE.fields_by_name['slide_id'].message_type = TSPMessages__pb2._UUID
_COMMANDBUILDUPDATECHUNKCOUNTARCHIVE.fields_by_name['drawable_ids'].message_type = TSPMessages__pb2._UUID
_COMMANDBUILDUPDATECHUNKCOUNTARCHIVE.fields_by_name['expected_delivery_style_tuples'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDBUILDUPDATECHUNKCOUNTARCHIVE.fields_by_name['chunks_to_add'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDBUILDUPDATECHUNKCOUNTARCHIVE.fields_by_name['identifiers_for_chunks_to_insert_after'].message_type = KNArchives__pb2._BUILDCHUNKIDENTIFIERARCHIVE
_COMMANDBUILDUPDATECHUNKCOUNTARCHIVE.fields_by_name['identifiers_for_chunks_to_remove'].message_type = KNArchives__pb2._BUILDCHUNKIDENTIFIERARCHIVE
_COMMANDBUILDUPDATECHUNKCOUNTARCHIVE.fields_by_name['tuples_to_update'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDBUILDUPDATECHUNKCOUNTARCHIVE.fields_by_name['old_tuples_to_update'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDBUILDUPDATECHUNKCOUNTARCHIVE.fields_by_name['identifiers_for_added_chunks'].message_type = KNArchives__pb2._BUILDCHUNKIDENTIFIERARCHIVE
_COMMANDBUILDUPDATECHUNKCOUNTARCHIVE.fields_by_name['generated_identifiers'].message_type = KNArchives__pb2._BUILDCHUNKIDENTIFIERARCHIVE
_COMMANDBUILDUPDATECHUNKCOUNTARCHIVE.fields_by_name['removed_chunks'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDBUILDUPDATECHUNKCOUNTARCHIVE.fields_by_name['identifiers_for_chunks_prior_to_removed_chunks'].message_type = KNArchives__pb2._BUILDCHUNKIDENTIFIERARCHIVE
_COMMANDBUILDUPDATECHUNKCOUNTARCHIVE.fields_by_name['old_delivery_style_tuples'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDBUILDUPDATECHUNKCOUNTARCHIVE.fields_by_name['old_chunk_identifiers'].message_type = KNArchives__pb2._BUILDCHUNKIDENTIFIERARCHIVE
_COMMANDBUILDUPDATECHUNKCOUNTARCHIVE.fields_by_name['working_builds'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDBUILDUPDATECHUNKCOUNTARCHIVE.fields_by_name['chunks_removed_during_undo'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDBUILDUPDATECHUNKCOUNTARCHIVE.fields_by_name['chunks_added_during_undo'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDBUILDCHUNKSETVALUEARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDBUILDCHUNKSETVALUEARCHIVE.fields_by_name['tuples_to_update'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDBUILDCHUNKSETVALUEARCHIVE.fields_by_name['old_tuples_to_update'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDTRANSITIONSETVALUEARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDTRANSITIONSETVALUEARCHIVE.fields_by_name['slide_node_id_path'].message_type = TSPMessages__pb2._UUIDPATH
_COMMANDTRANSITIONSETVALUEARCHIVE.fields_by_name['old_attributes'].message_type = KNArchives__pb2._TRANSITIONATTRIBUTESARCHIVE
_COMMANDTRANSITIONSETVALUEARCHIVE.fields_by_name['attributes'].message_type = KNArchives__pb2._TRANSITIONATTRIBUTESARCHIVE
_COMMANDSHOWSETSLIDENUMBERVISIBILITYARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSHOWSETSLIDENUMBERVISIBILITYARCHIVE.fields_by_name['ids_of_slide_nodes_to_skip'].message_type = TSPMessages__pb2._UUID
_COMMANDSHOWSETSLIDENUMBERVISIBILITYARCHIVE.fields_by_name['ids_of_slide_nodes_already_correct'].message_type = TSPMessages__pb2._UUID
_COMMANDMASTERSETTHUMBNAILTEXTARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDMASTERSETTHUMBNAILTEXTARCHIVE.fields_by_name['master_id'].message_type = TSPMessages__pb2._UUID
_COMMANDMASTERSETBODYSTYLESARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDMASTERSETBODYSTYLESARCHIVE.fields_by_name['master_id'].message_type = TSPMessages__pb2._UUID
_COMMANDMASTERSETBODYSTYLESARCHIVE.fields_by_name['new_paragraph_styles'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDMASTERSETBODYSTYLESARCHIVE.fields_by_name['new_list_styles'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDMASTERSETBODYSTYLESARCHIVE.fields_by_name['old_paragraph_styles'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDMASTERSETBODYSTYLESARCHIVE.fields_by_name['old_list_styles'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDCHANGEMASTERSLIDEARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDCHANGEMASTERSLIDEARCHIVE.fields_by_name['slide_id_path'].message_type = TSPMessages__pb2._UUIDPATH
_COMMANDCHANGEMASTERSLIDEARCHIVE.fields_by_name['master_node'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDCHANGEMASTERSLIDEARCHIVE.fields_by_name['old_master_node'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDCHANGEMASTERSLIDEARCHIVE.fields_by_name['target_prototype'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDEPRIMITIVESETMASTERARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSLIDEPRIMITIVESETMASTERARCHIVE.fields_by_name['slide_id_path'].message_type = TSPMessages__pb2._UUIDPATH
_COMMANDSLIDEPRIMITIVESETMASTERARCHIVE.fields_by_name['master_id'].message_type = TSPMessages__pb2._UUID
_COMMANDSLIDEPRIMITIVESETMASTERARCHIVE.fields_by_name['old_master_node'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSLIDERESETMASTERBACKGROUNDOBJECTSARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSLIDERESETMASTERBACKGROUNDOBJECTSARCHIVE.fields_by_name['slide_id_path'].message_type = TSPMessages__pb2._UUIDPATH
_COMMANDSHOWSETSOUNDTRACK.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSHOWSETSOUNDTRACK.fields_by_name['show'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSHOWSETSOUNDTRACK.fields_by_name['soundtrack'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSHOWSETSOUNDTRACK.fields_by_name['old_soundtrack'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSOUNDTRACKSETVALUE_PROPERTYVALUE.fields_by_name['mode_value'].enum_type = KNArchives__pb2._SOUNDTRACK_SOUNDTRACKMODE
_COMMANDSOUNDTRACKSETVALUE_PROPERTYVALUE.fields_by_name['media_reference_values'].message_type = TSPMessages__pb2._DATAREFERENCE
_COMMANDSOUNDTRACKSETVALUE_PROPERTYVALUE.containing_type = _COMMANDSOUNDTRACKSETVALUE
_COMMANDSOUNDTRACKSETVALUE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSOUNDTRACKSETVALUE.fields_by_name['soundtrack_id'].message_type = TSPMessages__pb2._UUID
_COMMANDSOUNDTRACKSETVALUE.fields_by_name['old_value'].message_type = _COMMANDSOUNDTRACKSETVALUE_PROPERTYVALUE
_COMMANDSOUNDTRACKSETVALUE.fields_by_name['new_value'].message_type = _COMMANDSOUNDTRACKSETVALUE_PROPERTYVALUE
_COMMANDSLIDEUPDATEMASTERDRAWABLES.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSLIDEUPDATEMASTERDRAWABLES.fields_by_name['slide_id'].message_type = TSPMessages__pb2._UUID
_COMMANDSLIDEUPDATEMASTERDRAWABLES.fields_by_name['id_placement_operation_args'].message_type = TSKArchives__pb2._IDPLACEMENTOPERATIONARGS
_COMMANDSLIDEUPDATEMASTERDRAWABLES.fields_by_name['old_child_infos_for_undo'].message_type = TSPMessages__pb2._REFERENCE
_CHARTINFOGEOMETRYCOMMANDARCHIVE.fields_by_name['super'].message_type = TSDCommandArchives__pb2._INFOGEOMETRYCOMMANDARCHIVE
_CHARTINFOGEOMETRYCOMMANDARCHIVE.fields_by_name['previous_legend_offset'].message_type = TSPMessages__pb2._POINT
_CHARTINFOGEOMETRYCOMMANDARCHIVE.fields_by_name['previous_legend_size'].message_type = TSPMessages__pb2._SIZE
_CHARTINFOGEOMETRYCOMMANDARCHIVE.fields_by_name['adjusted_legend_offset'].message_type = TSPMessages__pb2._POINT
_CHARTINFOGEOMETRYCOMMANDARCHIVE.fields_by_name['adjusted_legend_size'].message_type = TSPMessages__pb2._SIZE
_CANVASSELECTIONTRANSFORMERARCHIVE.fields_by_name['transformer_helper'].message_type = TSDCommandArchives__pb2._INFOCOLLECTIONSELECTIONTRANSFORMERHELPERARCHIVE
_CANVASSELECTIONTRANSFORMERARCHIVE.fields_by_name['build_chunk_ids'].message_type = KNArchives__pb2._BUILDCHUNKIDENTIFIERARCHIVE
_CANVASSELECTIONTRANSFORMERARCHIVE.fields_by_name['action_build_ids'].message_type = TSPMessages__pb2._UUID
_CANVASSELECTIONTRANSFORMERARCHIVE.fields_by_name['originally_selected_drawable_uuids'].message_type = TSPMessages__pb2._UUID
_DOCUMENTSELECTIONTRANSFORMERARCHIVE.fields_by_name['document_selection'].message_type = TSPMessages__pb2._REFERENCE
_NOTECANVASSELECTIONTRANSFORMERARCHIVE.fields_by_name['transformer_helper'].message_type = TSDCommandArchives__pb2._INFOCOLLECTIONSELECTIONTRANSFORMERHELPERARCHIVE
_OUTLINECANVASSELECTIONTRANSFORMERARCHIVE.fields_by_name['canvas_selection_transformer'].message_type = TSPMessages__pb2._REFERENCE
_OUTLINECANVASSELECTIONTRANSFORMERARCHIVE.fields_by_name['storage_uuid_path'].message_type = TSPMessages__pb2._UUIDPATH
_SLIDECOLLECTIONSELECTIONTRANSFORMERHELPERARCHIVE.fields_by_name['slide_nodes'].message_type = TSPMessages__pb2._UUIDPATH
_SLIDECOLLECTIONSELECTIONTRANSFORMERHELPERARCHIVE.fields_by_name['slide_node_to_edit'].message_type = TSPMessages__pb2._UUIDPATH
_SLIDECOLLECTIONSELECTIONTRANSFORMERARCHIVE.fields_by_name['transformer_helper'].message_type = _SLIDECOLLECTIONSELECTIONTRANSFORMERHELPERARCHIVE
_OUTLINESELECTIONTRANSFORMERARCHIVE.fields_by_name['transformer_helper'].message_type = _SLIDECOLLECTIONSELECTIONTRANSFORMERHELPERARCHIVE
_OUTLINESELECTIONTRANSFORMERARCHIVE.fields_by_name['selection_range_addresses'].message_type = TSKArchives__pb2._RANGEADDRESS
DESCRIPTOR.message_types_by_name['UIStateCommandGroupArchive'] = _UISTATECOMMANDGROUPARCHIVE
DESCRIPTOR.message_types_by_name['CommandSlideInsertDrawablesArchive'] = _COMMANDSLIDEINSERTDRAWABLESARCHIVE
DESCRIPTOR.message_types_by_name['CommandSlideSetPlaceholdersForTagsArchive'] = _COMMANDSLIDESETPLACEHOLDERSFORTAGSARCHIVE
DESCRIPTOR.message_types_by_name['CommandMasterSlideSetPlaceholderForTagArchive'] = _COMMANDMASTERSLIDESETPLACEHOLDERFORTAGARCHIVE
DESCRIPTOR.message_types_by_name['CommandSlidePropagateSetPlaceholderForTagArchive'] = _COMMANDSLIDEPROPAGATESETPLACEHOLDERFORTAGARCHIVE
DESCRIPTOR.message_types_by_name['CommandSlideRemoveDrawableArchive'] = _COMMANDSLIDEREMOVEDRAWABLEARCHIVE
DESCRIPTOR.message_types_by_name['CommandSlideMoveDrawableZOrderArchive'] = _COMMANDSLIDEMOVEDRAWABLEZORDERARCHIVE
DESCRIPTOR.message_types_by_name['CommandSlideNodeSetPropertyArchive'] = _COMMANDSLIDENODESETPROPERTYARCHIVE
DESCRIPTOR.message_types_by_name['CommandSlideNodeSetViewStatePropertyArchive'] = _COMMANDSLIDENODESETVIEWSTATEPROPERTYARCHIVE
DESCRIPTOR.message_types_by_name['CommandSlideSetBackgroundFillArchive'] = _COMMANDSLIDESETBACKGROUNDFILLARCHIVE
DESCRIPTOR.message_types_by_name['CommandSlideSetStyleArchive'] = _COMMANDSLIDESETSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['CommandShowMarkOutOfSyncRecordingArchive'] = _COMMANDSHOWMARKOUTOFSYNCRECORDINGARCHIVE
DESCRIPTOR.message_types_by_name['CommandShowMarkOutOfSyncRecordingIfNeededArchive'] = _COMMANDSHOWMARKOUTOFSYNCRECORDINGIFNEEDEDARCHIVE
DESCRIPTOR.message_types_by_name['CommandShowRemoveRecordingArchive'] = _COMMANDSHOWREMOVERECORDINGARCHIVE
DESCRIPTOR.message_types_by_name['CommandShowReplaceRecordingArchive'] = _COMMANDSHOWREPLACERECORDINGARCHIVE
DESCRIPTOR.message_types_by_name['CommandShowSetValueArchive'] = _COMMANDSHOWSETVALUEARCHIVE
DESCRIPTOR.message_types_by_name['CommandShowInsertSlideArchive'] = _COMMANDSHOWINSERTSLIDEARCHIVE
DESCRIPTOR.message_types_by_name['CommandShowMoveSlideArchive'] = _COMMANDSHOWMOVESLIDEARCHIVE
DESCRIPTOR.message_types_by_name['CommandShowRemoveSlideArchive'] = _COMMANDSHOWREMOVESLIDEARCHIVE
DESCRIPTOR.message_types_by_name['CommandShowChangeThemeArchive'] = _COMMANDSHOWCHANGETHEMEARCHIVE
DESCRIPTOR.message_types_by_name['CommandShowChangeSlideSizeArchive'] = _COMMANDSHOWCHANGESLIDESIZEARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetThemeCustomEffectTimingCurveArchive'] = _COMMANDSETTHEMECUSTOMEFFECTTIMINGCURVEARCHIVE
DESCRIPTOR.message_types_by_name['CommandMoveMastersArchive'] = _COMMANDMOVEMASTERSARCHIVE
DESCRIPTOR.message_types_by_name['CommandInsertMasterArchive'] = _COMMANDINSERTMASTERARCHIVE
DESCRIPTOR.message_types_by_name['CommandPrimitiveInsertMasterArchive'] = _COMMANDPRIMITIVEINSERTMASTERARCHIVE
DESCRIPTOR.message_types_by_name['CommandRemoveMasterArchive'] = _COMMANDREMOVEMASTERARCHIVE
DESCRIPTOR.message_types_by_name['CommandPrimitiveRemoveMasterArchive'] = _COMMANDPRIMITIVEREMOVEMASTERARCHIVE
DESCRIPTOR.message_types_by_name['CommandSlideInsertBuildArchive'] = _COMMANDSLIDEINSERTBUILDARCHIVE
DESCRIPTOR.message_types_by_name['InsertBuildDescriptionArchive'] = _INSERTBUILDDESCRIPTIONARCHIVE
DESCRIPTOR.message_types_by_name['UndoObjectArchive'] = _UNDOOBJECTARCHIVE
DESCRIPTOR.message_types_by_name['CommandSlideRemoveBuildArchive'] = _COMMANDSLIDEREMOVEBUILDARCHIVE
DESCRIPTOR.message_types_by_name['RemoveBuildDescriptionArchive'] = _REMOVEBUILDDESCRIPTIONARCHIVE
DESCRIPTOR.message_types_by_name['CommandSlideInsertBuildChunkArchive'] = _COMMANDSLIDEINSERTBUILDCHUNKARCHIVE
DESCRIPTOR.message_types_by_name['CommandSlideRemoveBuildChunkArchive'] = _COMMANDSLIDEREMOVEBUILDCHUNKARCHIVE
DESCRIPTOR.message_types_by_name['CommandSlideMoveBuildChunksArchive'] = _COMMANDSLIDEMOVEBUILDCHUNKSARCHIVE
DESCRIPTOR.message_types_by_name['CommandBuildSetValueArchive'] = _COMMANDBUILDSETVALUEARCHIVE
DESCRIPTOR.message_types_by_name['CommandBuildUpdateChunkReferentsArchive'] = _COMMANDBUILDUPDATECHUNKREFERENTSARCHIVE
DESCRIPTOR.message_types_by_name['CommandBuildUpdateChunkCountArchive'] = _COMMANDBUILDUPDATECHUNKCOUNTARCHIVE
DESCRIPTOR.message_types_by_name['CommandBuildChunkSetValueArchive'] = _COMMANDBUILDCHUNKSETVALUEARCHIVE
DESCRIPTOR.message_types_by_name['CommandTransitionSetValueArchive'] = _COMMANDTRANSITIONSETVALUEARCHIVE
DESCRIPTOR.message_types_by_name['CommandShowSetSlideNumberVisibilityArchive'] = _COMMANDSHOWSETSLIDENUMBERVISIBILITYARCHIVE
DESCRIPTOR.message_types_by_name['CommandMasterSetThumbnailTextArchive'] = _COMMANDMASTERSETTHUMBNAILTEXTARCHIVE
DESCRIPTOR.message_types_by_name['CommandMasterSetBodyStylesArchive'] = _COMMANDMASTERSETBODYSTYLESARCHIVE
DESCRIPTOR.message_types_by_name['CommandChangeMasterSlideArchive'] = _COMMANDCHANGEMASTERSLIDEARCHIVE
DESCRIPTOR.message_types_by_name['CommandSlidePrimitiveSetMasterArchive'] = _COMMANDSLIDEPRIMITIVESETMASTERARCHIVE
DESCRIPTOR.message_types_by_name['CommandSlideResetMasterBackgroundObjectsArchive'] = _COMMANDSLIDERESETMASTERBACKGROUNDOBJECTSARCHIVE
DESCRIPTOR.message_types_by_name['CommandShowSetSoundtrack'] = _COMMANDSHOWSETSOUNDTRACK
DESCRIPTOR.message_types_by_name['CommandSoundtrackSetValue'] = _COMMANDSOUNDTRACKSETVALUE
DESCRIPTOR.message_types_by_name['CommandSlideUpdateMasterDrawables'] = _COMMANDSLIDEUPDATEMASTERDRAWABLES
DESCRIPTOR.message_types_by_name['ChartInfoGeometryCommandArchive'] = _CHARTINFOGEOMETRYCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['CanvasSelectionTransformerArchive'] = _CANVASSELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['ActionGhostSelectionTransformerArchive'] = _ACTIONGHOSTSELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['DocumentSelectionTransformerArchive'] = _DOCUMENTSELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['NoteCanvasSelectionTransformerArchive'] = _NOTECANVASSELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['OutlineCanvasSelectionTransformerArchive'] = _OUTLINECANVASSELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['SlideCollectionSelectionTransformerHelperArchive'] = _SLIDECOLLECTIONSELECTIONTRANSFORMERHELPERARCHIVE
DESCRIPTOR.message_types_by_name['SlideCollectionSelectionTransformerArchive'] = _SLIDECOLLECTIONSELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['OutlineSelectionTransformerArchive'] = _OUTLINESELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.enum_types_by_name['AnimationReferent'] = _ANIMATIONREFERENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UIStateCommandGroupArchive = _reflection.GeneratedProtocolMessageType('UIStateCommandGroupArchive', (_message.Message,), dict(
  DESCRIPTOR = _UISTATECOMMANDGROUPARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.UIStateCommandGroupArchive)
  ))
_sym_db.RegisterMessage(UIStateCommandGroupArchive)

CommandSlideInsertDrawablesArchive = _reflection.GeneratedProtocolMessageType('CommandSlideInsertDrawablesArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSLIDEINSERTDRAWABLESARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandSlideInsertDrawablesArchive)
  ))
_sym_db.RegisterMessage(CommandSlideInsertDrawablesArchive)

CommandSlideSetPlaceholdersForTagsArchive = _reflection.GeneratedProtocolMessageType('CommandSlideSetPlaceholdersForTagsArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSLIDESETPLACEHOLDERSFORTAGSARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandSlideSetPlaceholdersForTagsArchive)
  ))
_sym_db.RegisterMessage(CommandSlideSetPlaceholdersForTagsArchive)

CommandMasterSlideSetPlaceholderForTagArchive = _reflection.GeneratedProtocolMessageType('CommandMasterSlideSetPlaceholderForTagArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDMASTERSLIDESETPLACEHOLDERFORTAGARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandMasterSlideSetPlaceholderForTagArchive)
  ))
_sym_db.RegisterMessage(CommandMasterSlideSetPlaceholderForTagArchive)

CommandSlidePropagateSetPlaceholderForTagArchive = _reflection.GeneratedProtocolMessageType('CommandSlidePropagateSetPlaceholderForTagArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSLIDEPROPAGATESETPLACEHOLDERFORTAGARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandSlidePropagateSetPlaceholderForTagArchive)
  ))
_sym_db.RegisterMessage(CommandSlidePropagateSetPlaceholderForTagArchive)

CommandSlideRemoveDrawableArchive = _reflection.GeneratedProtocolMessageType('CommandSlideRemoveDrawableArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSLIDEREMOVEDRAWABLEARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandSlideRemoveDrawableArchive)
  ))
_sym_db.RegisterMessage(CommandSlideRemoveDrawableArchive)

CommandSlideMoveDrawableZOrderArchive = _reflection.GeneratedProtocolMessageType('CommandSlideMoveDrawableZOrderArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSLIDEMOVEDRAWABLEZORDERARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandSlideMoveDrawableZOrderArchive)
  ))
_sym_db.RegisterMessage(CommandSlideMoveDrawableZOrderArchive)

CommandSlideNodeSetPropertyArchive = _reflection.GeneratedProtocolMessageType('CommandSlideNodeSetPropertyArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSLIDENODESETPROPERTYARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandSlideNodeSetPropertyArchive)
  ))
_sym_db.RegisterMessage(CommandSlideNodeSetPropertyArchive)

CommandSlideNodeSetViewStatePropertyArchive = _reflection.GeneratedProtocolMessageType('CommandSlideNodeSetViewStatePropertyArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSLIDENODESETVIEWSTATEPROPERTYARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandSlideNodeSetViewStatePropertyArchive)
  ))
_sym_db.RegisterMessage(CommandSlideNodeSetViewStatePropertyArchive)

CommandSlideSetBackgroundFillArchive = _reflection.GeneratedProtocolMessageType('CommandSlideSetBackgroundFillArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSLIDESETBACKGROUNDFILLARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandSlideSetBackgroundFillArchive)
  ))
_sym_db.RegisterMessage(CommandSlideSetBackgroundFillArchive)

CommandSlideSetStyleArchive = _reflection.GeneratedProtocolMessageType('CommandSlideSetStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSLIDESETSTYLEARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandSlideSetStyleArchive)
  ))
_sym_db.RegisterMessage(CommandSlideSetStyleArchive)

CommandShowMarkOutOfSyncRecordingArchive = _reflection.GeneratedProtocolMessageType('CommandShowMarkOutOfSyncRecordingArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSHOWMARKOUTOFSYNCRECORDINGARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandShowMarkOutOfSyncRecordingArchive)
  ))
_sym_db.RegisterMessage(CommandShowMarkOutOfSyncRecordingArchive)

CommandShowMarkOutOfSyncRecordingIfNeededArchive = _reflection.GeneratedProtocolMessageType('CommandShowMarkOutOfSyncRecordingIfNeededArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSHOWMARKOUTOFSYNCRECORDINGIFNEEDEDARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandShowMarkOutOfSyncRecordingIfNeededArchive)
  ))
_sym_db.RegisterMessage(CommandShowMarkOutOfSyncRecordingIfNeededArchive)

CommandShowRemoveRecordingArchive = _reflection.GeneratedProtocolMessageType('CommandShowRemoveRecordingArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSHOWREMOVERECORDINGARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandShowRemoveRecordingArchive)
  ))
_sym_db.RegisterMessage(CommandShowRemoveRecordingArchive)

CommandShowReplaceRecordingArchive = _reflection.GeneratedProtocolMessageType('CommandShowReplaceRecordingArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSHOWREPLACERECORDINGARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandShowReplaceRecordingArchive)
  ))
_sym_db.RegisterMessage(CommandShowReplaceRecordingArchive)

CommandShowSetValueArchive = _reflection.GeneratedProtocolMessageType('CommandShowSetValueArchive', (_message.Message,), dict(

  PropertyValue = _reflection.GeneratedProtocolMessageType('PropertyValue', (_message.Message,), dict(
    DESCRIPTOR = _COMMANDSHOWSETVALUEARCHIVE_PROPERTYVALUE,
    __module__ = 'KNCommandArchives_pb2'
    # @@protoc_insertion_point(class_scope:KN.CommandShowSetValueArchive.PropertyValue)
    ))
  ,
  DESCRIPTOR = _COMMANDSHOWSETVALUEARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandShowSetValueArchive)
  ))
_sym_db.RegisterMessage(CommandShowSetValueArchive)
_sym_db.RegisterMessage(CommandShowSetValueArchive.PropertyValue)

CommandShowInsertSlideArchive = _reflection.GeneratedProtocolMessageType('CommandShowInsertSlideArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSHOWINSERTSLIDEARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandShowInsertSlideArchive)
  ))
_sym_db.RegisterMessage(CommandShowInsertSlideArchive)

CommandShowMoveSlideArchive = _reflection.GeneratedProtocolMessageType('CommandShowMoveSlideArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSHOWMOVESLIDEARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandShowMoveSlideArchive)
  ))
_sym_db.RegisterMessage(CommandShowMoveSlideArchive)

CommandShowRemoveSlideArchive = _reflection.GeneratedProtocolMessageType('CommandShowRemoveSlideArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSHOWREMOVESLIDEARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandShowRemoveSlideArchive)
  ))
_sym_db.RegisterMessage(CommandShowRemoveSlideArchive)

CommandShowChangeThemeArchive = _reflection.GeneratedProtocolMessageType('CommandShowChangeThemeArchive', (_message.Message,), dict(

  IdentifierToStyleMap = _reflection.GeneratedProtocolMessageType('IdentifierToStyleMap', (_message.Message,), dict(
    DESCRIPTOR = _COMMANDSHOWCHANGETHEMEARCHIVE_IDENTIFIERTOSTYLEMAP,
    __module__ = 'KNCommandArchives_pb2'
    # @@protoc_insertion_point(class_scope:KN.CommandShowChangeThemeArchive.IdentifierToStyleMap)
    ))
  ,
  DESCRIPTOR = _COMMANDSHOWCHANGETHEMEARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandShowChangeThemeArchive)
  ))
_sym_db.RegisterMessage(CommandShowChangeThemeArchive)
_sym_db.RegisterMessage(CommandShowChangeThemeArchive.IdentifierToStyleMap)

CommandShowChangeSlideSizeArchive = _reflection.GeneratedProtocolMessageType('CommandShowChangeSlideSizeArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSHOWCHANGESLIDESIZEARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandShowChangeSlideSizeArchive)
  ))
_sym_db.RegisterMessage(CommandShowChangeSlideSizeArchive)

CommandSetThemeCustomEffectTimingCurveArchive = _reflection.GeneratedProtocolMessageType('CommandSetThemeCustomEffectTimingCurveArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETTHEMECUSTOMEFFECTTIMINGCURVEARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandSetThemeCustomEffectTimingCurveArchive)
  ))
_sym_db.RegisterMessage(CommandSetThemeCustomEffectTimingCurveArchive)

CommandMoveMastersArchive = _reflection.GeneratedProtocolMessageType('CommandMoveMastersArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDMOVEMASTERSARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandMoveMastersArchive)
  ))
_sym_db.RegisterMessage(CommandMoveMastersArchive)

CommandInsertMasterArchive = _reflection.GeneratedProtocolMessageType('CommandInsertMasterArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDINSERTMASTERARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandInsertMasterArchive)
  ))
_sym_db.RegisterMessage(CommandInsertMasterArchive)

CommandPrimitiveInsertMasterArchive = _reflection.GeneratedProtocolMessageType('CommandPrimitiveInsertMasterArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDPRIMITIVEINSERTMASTERARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandPrimitiveInsertMasterArchive)
  ))
_sym_db.RegisterMessage(CommandPrimitiveInsertMasterArchive)

CommandRemoveMasterArchive = _reflection.GeneratedProtocolMessageType('CommandRemoveMasterArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDREMOVEMASTERARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandRemoveMasterArchive)
  ))
_sym_db.RegisterMessage(CommandRemoveMasterArchive)

CommandPrimitiveRemoveMasterArchive = _reflection.GeneratedProtocolMessageType('CommandPrimitiveRemoveMasterArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDPRIMITIVEREMOVEMASTERARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandPrimitiveRemoveMasterArchive)
  ))
_sym_db.RegisterMessage(CommandPrimitiveRemoveMasterArchive)

CommandSlideInsertBuildArchive = _reflection.GeneratedProtocolMessageType('CommandSlideInsertBuildArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSLIDEINSERTBUILDARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandSlideInsertBuildArchive)
  ))
_sym_db.RegisterMessage(CommandSlideInsertBuildArchive)

InsertBuildDescriptionArchive = _reflection.GeneratedProtocolMessageType('InsertBuildDescriptionArchive', (_message.Message,), dict(
  DESCRIPTOR = _INSERTBUILDDESCRIPTIONARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.InsertBuildDescriptionArchive)
  ))
_sym_db.RegisterMessage(InsertBuildDescriptionArchive)

UndoObjectArchive = _reflection.GeneratedProtocolMessageType('UndoObjectArchive', (_message.Message,), dict(
  DESCRIPTOR = _UNDOOBJECTARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.UndoObjectArchive)
  ))
_sym_db.RegisterMessage(UndoObjectArchive)

CommandSlideRemoveBuildArchive = _reflection.GeneratedProtocolMessageType('CommandSlideRemoveBuildArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSLIDEREMOVEBUILDARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandSlideRemoveBuildArchive)
  ))
_sym_db.RegisterMessage(CommandSlideRemoveBuildArchive)

RemoveBuildDescriptionArchive = _reflection.GeneratedProtocolMessageType('RemoveBuildDescriptionArchive', (_message.Message,), dict(
  DESCRIPTOR = _REMOVEBUILDDESCRIPTIONARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.RemoveBuildDescriptionArchive)
  ))
_sym_db.RegisterMessage(RemoveBuildDescriptionArchive)

CommandSlideInsertBuildChunkArchive = _reflection.GeneratedProtocolMessageType('CommandSlideInsertBuildChunkArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSLIDEINSERTBUILDCHUNKARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandSlideInsertBuildChunkArchive)
  ))
_sym_db.RegisterMessage(CommandSlideInsertBuildChunkArchive)

CommandSlideRemoveBuildChunkArchive = _reflection.GeneratedProtocolMessageType('CommandSlideRemoveBuildChunkArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSLIDEREMOVEBUILDCHUNKARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandSlideRemoveBuildChunkArchive)
  ))
_sym_db.RegisterMessage(CommandSlideRemoveBuildChunkArchive)

CommandSlideMoveBuildChunksArchive = _reflection.GeneratedProtocolMessageType('CommandSlideMoveBuildChunksArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSLIDEMOVEBUILDCHUNKSARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandSlideMoveBuildChunksArchive)
  ))
_sym_db.RegisterMessage(CommandSlideMoveBuildChunksArchive)

CommandBuildSetValueArchive = _reflection.GeneratedProtocolMessageType('CommandBuildSetValueArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDBUILDSETVALUEARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandBuildSetValueArchive)
  ))
_sym_db.RegisterMessage(CommandBuildSetValueArchive)

CommandBuildUpdateChunkReferentsArchive = _reflection.GeneratedProtocolMessageType('CommandBuildUpdateChunkReferentsArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDBUILDUPDATECHUNKREFERENTSARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandBuildUpdateChunkReferentsArchive)
  ))
_sym_db.RegisterMessage(CommandBuildUpdateChunkReferentsArchive)

CommandBuildUpdateChunkCountArchive = _reflection.GeneratedProtocolMessageType('CommandBuildUpdateChunkCountArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDBUILDUPDATECHUNKCOUNTARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandBuildUpdateChunkCountArchive)
  ))
_sym_db.RegisterMessage(CommandBuildUpdateChunkCountArchive)

CommandBuildChunkSetValueArchive = _reflection.GeneratedProtocolMessageType('CommandBuildChunkSetValueArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDBUILDCHUNKSETVALUEARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandBuildChunkSetValueArchive)
  ))
_sym_db.RegisterMessage(CommandBuildChunkSetValueArchive)

CommandTransitionSetValueArchive = _reflection.GeneratedProtocolMessageType('CommandTransitionSetValueArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDTRANSITIONSETVALUEARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandTransitionSetValueArchive)
  ))
_sym_db.RegisterMessage(CommandTransitionSetValueArchive)

CommandShowSetSlideNumberVisibilityArchive = _reflection.GeneratedProtocolMessageType('CommandShowSetSlideNumberVisibilityArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSHOWSETSLIDENUMBERVISIBILITYARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandShowSetSlideNumberVisibilityArchive)
  ))
_sym_db.RegisterMessage(CommandShowSetSlideNumberVisibilityArchive)

CommandMasterSetThumbnailTextArchive = _reflection.GeneratedProtocolMessageType('CommandMasterSetThumbnailTextArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDMASTERSETTHUMBNAILTEXTARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandMasterSetThumbnailTextArchive)
  ))
_sym_db.RegisterMessage(CommandMasterSetThumbnailTextArchive)

CommandMasterSetBodyStylesArchive = _reflection.GeneratedProtocolMessageType('CommandMasterSetBodyStylesArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDMASTERSETBODYSTYLESARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandMasterSetBodyStylesArchive)
  ))
_sym_db.RegisterMessage(CommandMasterSetBodyStylesArchive)

CommandChangeMasterSlideArchive = _reflection.GeneratedProtocolMessageType('CommandChangeMasterSlideArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDCHANGEMASTERSLIDEARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandChangeMasterSlideArchive)
  ))
_sym_db.RegisterMessage(CommandChangeMasterSlideArchive)

CommandSlidePrimitiveSetMasterArchive = _reflection.GeneratedProtocolMessageType('CommandSlidePrimitiveSetMasterArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSLIDEPRIMITIVESETMASTERARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandSlidePrimitiveSetMasterArchive)
  ))
_sym_db.RegisterMessage(CommandSlidePrimitiveSetMasterArchive)

CommandSlideResetMasterBackgroundObjectsArchive = _reflection.GeneratedProtocolMessageType('CommandSlideResetMasterBackgroundObjectsArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSLIDERESETMASTERBACKGROUNDOBJECTSARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandSlideResetMasterBackgroundObjectsArchive)
  ))
_sym_db.RegisterMessage(CommandSlideResetMasterBackgroundObjectsArchive)

CommandShowSetSoundtrack = _reflection.GeneratedProtocolMessageType('CommandShowSetSoundtrack', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSHOWSETSOUNDTRACK,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandShowSetSoundtrack)
  ))
_sym_db.RegisterMessage(CommandShowSetSoundtrack)

CommandSoundtrackSetValue = _reflection.GeneratedProtocolMessageType('CommandSoundtrackSetValue', (_message.Message,), dict(

  PropertyValue = _reflection.GeneratedProtocolMessageType('PropertyValue', (_message.Message,), dict(
    DESCRIPTOR = _COMMANDSOUNDTRACKSETVALUE_PROPERTYVALUE,
    __module__ = 'KNCommandArchives_pb2'
    # @@protoc_insertion_point(class_scope:KN.CommandSoundtrackSetValue.PropertyValue)
    ))
  ,
  DESCRIPTOR = _COMMANDSOUNDTRACKSETVALUE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandSoundtrackSetValue)
  ))
_sym_db.RegisterMessage(CommandSoundtrackSetValue)
_sym_db.RegisterMessage(CommandSoundtrackSetValue.PropertyValue)

CommandSlideUpdateMasterDrawables = _reflection.GeneratedProtocolMessageType('CommandSlideUpdateMasterDrawables', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSLIDEUPDATEMASTERDRAWABLES,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandSlideUpdateMasterDrawables)
  ))
_sym_db.RegisterMessage(CommandSlideUpdateMasterDrawables)

ChartInfoGeometryCommandArchive = _reflection.GeneratedProtocolMessageType('ChartInfoGeometryCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTINFOGEOMETRYCOMMANDARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.ChartInfoGeometryCommandArchive)
  ))
_sym_db.RegisterMessage(ChartInfoGeometryCommandArchive)

CanvasSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('CanvasSelectionTransformerArchive', (_message.Message,), dict(
  DESCRIPTOR = _CANVASSELECTIONTRANSFORMERARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CanvasSelectionTransformerArchive)
  ))
_sym_db.RegisterMessage(CanvasSelectionTransformerArchive)

ActionGhostSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('ActionGhostSelectionTransformerArchive', (_message.Message,), dict(
  DESCRIPTOR = _ACTIONGHOSTSELECTIONTRANSFORMERARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.ActionGhostSelectionTransformerArchive)
  ))
_sym_db.RegisterMessage(ActionGhostSelectionTransformerArchive)

DocumentSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('DocumentSelectionTransformerArchive', (_message.Message,), dict(
  DESCRIPTOR = _DOCUMENTSELECTIONTRANSFORMERARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.DocumentSelectionTransformerArchive)
  ))
_sym_db.RegisterMessage(DocumentSelectionTransformerArchive)

NoteCanvasSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('NoteCanvasSelectionTransformerArchive', (_message.Message,), dict(
  DESCRIPTOR = _NOTECANVASSELECTIONTRANSFORMERARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.NoteCanvasSelectionTransformerArchive)
  ))
_sym_db.RegisterMessage(NoteCanvasSelectionTransformerArchive)

OutlineCanvasSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('OutlineCanvasSelectionTransformerArchive', (_message.Message,), dict(
  DESCRIPTOR = _OUTLINECANVASSELECTIONTRANSFORMERARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.OutlineCanvasSelectionTransformerArchive)
  ))
_sym_db.RegisterMessage(OutlineCanvasSelectionTransformerArchive)

SlideCollectionSelectionTransformerHelperArchive = _reflection.GeneratedProtocolMessageType('SlideCollectionSelectionTransformerHelperArchive', (_message.Message,), dict(
  DESCRIPTOR = _SLIDECOLLECTIONSELECTIONTRANSFORMERHELPERARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.SlideCollectionSelectionTransformerHelperArchive)
  ))
_sym_db.RegisterMessage(SlideCollectionSelectionTransformerHelperArchive)

SlideCollectionSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('SlideCollectionSelectionTransformerArchive', (_message.Message,), dict(
  DESCRIPTOR = _SLIDECOLLECTIONSELECTIONTRANSFORMERARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.SlideCollectionSelectionTransformerArchive)
  ))
_sym_db.RegisterMessage(SlideCollectionSelectionTransformerArchive)

OutlineSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('OutlineSelectionTransformerArchive', (_message.Message,), dict(
  DESCRIPTOR = _OUTLINESELECTIONTRANSFORMERARCHIVE,
  __module__ = 'KNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.OutlineSelectionTransformerArchive)
  ))
_sym_db.RegisterMessage(OutlineSelectionTransformerArchive)


# @@protoc_insertion_point(module_scope)
